from .stickers.add_sticker_to_set import AddStickerToSet
from .other.answer_callback_query import AnswerCallbackQuery
from .other.answer_inline_query import AnswerInlineQuery
from .other.answer_pre_checkout_query import AnswerPreCheckoutQuery
from .other.answer_shipping_query import AnswerShippingQuery
from .other.answer_web_app_query import AnswerWebAppQuery
from .chats.approve_chat_join_request import ApproveChatJoinRequest
from .messages.ask import Ask
from .chats.ban_chat_member import BanChatMember
from .chats.ban_chat_sender_chat import BanChatSenderChat
from .bot.close import Close
from .forums.close_forum_topic import CloseForumTopic
from .forums.close_general_forum_topic import CloseGeneralForumTopic
from .messages.copy_message import CopyMessage
from .messages.copy_messages import CopyMessages
from .chats.create_chat_invite_link import CreateChatInviteLink
from .chats.create_chat_subscription_invite_link import CreateChatSubscriptionInviteLink
from .forums.create_forum_topic import CreateForumTopic
from .other.create_invoice_link import CreateInvoiceLink
from .stickers.create_new_sticker_set import CreateNewStickerSet
from .chats.decline_chat_join_request import DeclineChatJoinRequest
from .chats.delete_chat_photo import DeleteChatPhoto
from .chats.delete_chat_sticker_set import DeleteChatStickerSet
from .forums.delete_forum_topic import DeleteForumTopic
from .messages.delete_message import DeleteMessage
from .messages.delete_messages import DeleteMessages
from .bot.delete_my_commands import DeleteMyCommands
from .stickers.delete_sticker_from_set import DeleteStickerFromSet
from .stickers.delete_sticker_set import DeleteStickerSet
from .bot.delete_webhook import DeleteWebhook
from .chats.demote_chat_member import DemoteChatMember
from .files.download_file import DownloadFile
from .chats.edit_chat_invite_link import EditChatInviteLink
from .chats.edit_chat_subscription_invite_link import EditChatSubscriptionInviteLink
from .forums.edit_forum_topic import EditForumTopic
from .forums.edit_general_forum_topic import EditGeneralForumTopic
from .messages.edit_message_caption import EditMessageCaption
from .messages.edit_message_checklist import EditMessageChecklist
from .messages.edit_message_live_location import EditMessageLiveLocation
from .messages.edit_message_media import EditMessageMedia
from .messages.edit_message_reply_markup import EditMessageReplyMarkup
from .messages.edit_message_text import EditMessageText
from .payments_and_business.edit_user_star_subscription import EditUserStarSubscription
from .chats.export_chat_invite_link import ExportChatInviteLink
from .messages.forward_message import ForwardMessage
from .messages.forward_messages import ForwardMessages
from .bot.get_available_gifts import GetAvailableGifts
from .payments_and_business.get_business_connection import GetBusinessConnection
from .chats.get_chat import GetChat
from .chats.get_chat_administrators import GetChatAdministrators
from .chats.get_chat_member import GetChatMember
from .chats.get_chat_member_count import GetChatMemberCount
from .chats.get_chat_menu_button import GetChatMenuButton
from .chats.get_custom_emoji_stickers import GetCustomEmojiStickers
from .files.get_file import GetFile
from .files.get_file_url import GetFileUrl
from .forums.get_forum_topic_icon_stickers import GetForumTopicIconStickers
from .other.get_game_high_scores import GetGameHighScores
from .bot.get_me import GetMe
from .bot.get_my_commands import GetMyCommands
from .bot.get_my_default_administrator_rights import GetMyDefaultAdministratorRights
from .bot.get_my_description import GetMyDescription
from .bot.get_my_name import GetMyName
from .bot.get_my_stars_balance import GetMyStarBalance
from .bot.get_my_short_description import GetMyShortDescription
from .payments_and_business.get_star_transactions import GetStarTransactions
from .stickers.get_sticker_set import GetStickerSet
from .bot.get_updates import GetUpdates
from .chats.get_user_chat_boosts import GetUserChatBoosts
from .chats.get_user_profile_photos import GetUserProfilePhotos
from .bot.get_webhook_info import GetWebhookInfo
from .forums.hide_general_forum_topic import HideGeneralForumTopic
from .chats.leave_chat import LeaveChat
from .bot.log_out import LogOut
from .chats.pin_chat_message import PinChatMessage
from .chats.promote_chat_member import PromoteChatMember
from .payments_and_business.refund_star_payment import RefundStarPayment
from .forums.reopen_forum_topic import ReopenForumTopic
from .forums.reopen_general_forum_topic import ReopenGeneralForumTopic
from .stickers.replace_sticker_in_set import ReplaceStickerInSet
from .chats.restrict_chat_member import RestrictChatMember
from .chats.revoke_chat_invite_link import RevokeChatInviteLink
from .messages.send_animation import SendAnimation
from .messages.send_audio import SendAudio
from .messages.send_chat_action import SendChatAction
from .messages.send_contact import SendContact
from .messages.send_checklist import SendChecklist
from .messages.send_dice import SendDice
from .messages.send_document import SendDocument
from .messages.send_game import SendGame
from .messages.send_gift import SendGift
from .messages.send_invoice import SendInvoice
from .messages.send_location import SendLocation
from .messages.send_media_from_file_id import SendMediaFromFileId
from .messages.send_media_group import SendMediaGroup
from .messages.send_message import SendMessage
from .messages.send_paid_media import SendPaidMedia
from .messages.send_photo import SendPhoto
from .messages.send_poll import SendPoll
from .messages.send_sticker import SendSticker
from .messages.send_venue import SendVenue
from .messages.send_video import SendVideo
from .messages.send_video_note import SendVideoNote
from .messages.send_voice import SendVoice
from .chats.set_chat_administrator_custom_title import SetChatAdministratorCustomTitle
from .chats.set_chat_description import SetChatDescription
from .chats.set_chat_menu_button import SetChatMenuButton
from .chats.set_chat_permissions import SetChatPermissions
from .chats.set_chat_photo import SetChatPhoto
from .chats.set_chat_sticker_set import SetChatStickerSet
from .chats.set_chat_title import SetChatTitle
from .stickers.set_custom_emoji_sticker_set_thumbnail import (
    SetCustomEmojiStickerSetThumbnail,
)
from .other.set_game_score import SetGameScore
from .messages.set_message_reaction import SetMessageReaction
from .bot.set_my_commands import SetMyCommands
from .bot.set_my_default_administrator_rights import SetMyDefaultAdministratorRights
from .bot.set_my_description import SetMyDescription
from .bot.set_my_name import SetMyName
from .bot.set_my_short_description import SetMyShortDescription
from .other.set_passport_data_errors import SetPassportDataErrors
from .stickers.set_sticker_emoji_list import SetStickerEmojiList
from .stickers.set_sticker_keywords import SetStickerKeywords
from .stickers.set_sticker_mask_position import SetStickerMaskPosition
from .stickers.set_sticker_position_in_set import SetStickerPositionInSet
from .stickers.set_sticker_set_thumbnail import SetStickerSetThumbnail
from .stickers.set_sticker_set_title import SetStickerSetTitle
from .other.set_user_emoji_status import SetUserEmojiStatus
from .bot.set_webhook import SetWebhook
from .messages.stop_message_live_location import StopMessageLiveLocation
from .messages.stop_poll import StopPoll
from .other.save_prepared_inline_message import SavePreparedInlineMessage
from .chats.unban_chat_member import UnbanChatMember
from .chats.unban_chat_sender_chat import UnbanChatSenderChat
from .forums.unhide_general_forum_topic import UnhideGeneralForumTopic
from .chats.unpin_all_chat_messages import UnpinAllChatMessages
from .forums.unpin_all_forum_topic_messages import UnpinAllForumTopicMessages
from .forums.unpin_all_general_forum_topic_messages import (
    UnpinAllGeneralForumTopicMessages,
)
from .chats.unpin_chat_message import UnpinChatMessage
from .chats.unrestrict_chat_member import UnRestrictChatMember
from .stickers.upload_sticker_file import UploadStickerFile

from .bot.runner import Runner

from .chats.verify_chat import VerifyChat
from .chats.verify_user import VerifyUser
from .chats.remove_chat_verification import RemoveChatVerification
from .chats.remove_user_verification import RemoveUserVerification

from .payments_and_business.read_business_message import ReadBusinessMessage
from .payments_and_business.delete_business_messages import DeleteBusinessMessages
from .payments_and_business.set_business_account_name import SetBusinessAccountName
from .payments_and_business.set_business_account_username import (
    SetBusinessAccountUsername,
)
from .payments_and_business.set_business_account_bio import SetBusinessAccountBio
from .payments_and_business.set_business_account_profile_photo import (
    SetBusinessAccountProfilePhoto,
)
from .payments_and_business.remove_business_account_profile_photo import (
    RemoveBusinessAccountProfilePhoto,
)
from .payments_and_business.set_business_account_gift_settings import (
    SetBusinessAccountGiftSettings,
)
from .payments_and_business.get_business_account_star_balance import (
    GetBusinessAccountStarBalance,
)
from .payments_and_business.transfer_business_account_stars import (
    TransferBusinessAccountStars,
)
from .payments_and_business.get_business_account_gifts import GetBusinessAccountGifts
from .payments_and_business.gift_premium_subscription import GiftPremiumSubscription
from .payments_and_business.convert_gift_to_stars import ConvertGiftToStars
from .payments_and_business.upgrade_gift import UpgradeGift
from .payments_and_business.transfer_gift import TransferGift
from .payments_and_business.post_story import PostStory
from .payments_and_business.edit_story import EditStory
from .payments_and_business.delete_story import DeleteStory


class TelegramBotMethods(
    AddStickerToSet,
    AnswerCallbackQuery,
    AnswerInlineQuery,
    AnswerPreCheckoutQuery,
    AnswerShippingQuery,
    AnswerWebAppQuery,
    ApproveChatJoinRequest,
    Ask,
    BanChatMember,
    BanChatSenderChat,
    Close,
    CloseForumTopic,
    CloseGeneralForumTopic,
    CopyMessage,
    CopyMessages,
    CreateChatInviteLink,
    CreateChatSubscriptionInviteLink,
    CreateForumTopic,
    CreateInvoiceLink,
    CreateNewStickerSet,
    ConvertGiftToStars,
    DeclineChatJoinRequest,
    DeleteChatPhoto,
    DeleteChatStickerSet,
    DeleteForumTopic,
    DeleteMessage,
    DeleteMessages,
    DeleteBusinessMessages,
    DeleteMyCommands,
    DeleteStickerFromSet,
    DeleteStickerSet,
    DeleteWebhook,
    DeleteStory,
    DemoteChatMember,
    DownloadFile,
    EditChatInviteLink,
    EditChatSubscriptionInviteLink,
    EditForumTopic,
    EditGeneralForumTopic,
    EditMessageCaption,
    EditMessageChecklist,
    EditMessageLiveLocation,
    EditMessageMedia,
    EditMessageReplyMarkup,
    EditMessageText,
    EditUserStarSubscription,
    EditStory,
    ExportChatInviteLink,
    ForwardMessage,
    ForwardMessages,
    GetAvailableGifts,
    GetBusinessConnection,
    GetChat,
    GetChatAdministrators,
    GetChatMember,
    GetChatMemberCount,
    GetChatMenuButton,
    GetCustomEmojiStickers,
    GetFile,
    GetFileUrl,
    GetForumTopicIconStickers,
    GetGameHighScores,
    GetMe,
    GetMyCommands,
    GetMyDefaultAdministratorRights,
    GetMyDescription,
    GetMyName,
    GetMyStarBalance,
    GetMyShortDescription,
    GetStarTransactions,
    GetStickerSet,
    GetUpdates,
    GetUserChatBoosts,
    GetUserProfilePhotos,
    GetWebhookInfo,
    GetBusinessAccountGifts,
    GetBusinessAccountStarBalance,
    GiftPremiumSubscription,
    HideGeneralForumTopic,
    LeaveChat,
    LogOut,
    PinChatMessage,
    PromoteChatMember,
    RefundStarPayment,
    ReopenForumTopic,
    ReopenGeneralForumTopic,
    ReplaceStickerInSet,
    RestrictChatMember,
    RevokeChatInviteLink,
    ReadBusinessMessage,
    SendAnimation,
    SendAudio,
    SendChatAction,
    SendContact,
    SendChecklist,
    SendDice,
    SendDocument,
    SendGame,
    SendGift,
    SendInvoice,
    SendLocation,
    SendMediaFromFileId,
    SendMediaGroup,
    SendMessage,
    SendPaidMedia,
    SendPhoto,
    SendPoll,
    SendSticker,
    SendVenue,
    SendVideo,
    SendVideoNote,
    SendVoice,
    SetChatAdministratorCustomTitle,
    SetChatDescription,
    SetChatMenuButton,
    SetChatPermissions,
    SetChatPhoto,
    SetChatStickerSet,
    SetChatTitle,
    SetCustomEmojiStickerSetThumbnail,
    SetGameScore,
    SetMessageReaction,
    SetMyCommands,
    SetMyDefaultAdministratorRights,
    SetMyDescription,
    SetMyName,
    SetMyShortDescription,
    SetPassportDataErrors,
    SetStickerEmojiList,
    SetStickerKeywords,
    SetStickerMaskPosition,
    SetStickerPositionInSet,
    SetStickerSetThumbnail,
    SetStickerSetTitle,
    SetUserEmojiStatus,
    SetWebhook,
    SetBusinessAccountName,
    SetBusinessAccountUsername,
    SetBusinessAccountBio,
    SetBusinessAccountProfilePhoto,
    SetBusinessAccountGiftSettings,
    StopMessageLiveLocation,
    StopPoll,
    SavePreparedInlineMessage,
    UnbanChatMember,
    UnbanChatSenderChat,
    UnhideGeneralForumTopic,
    UnpinAllChatMessages,
    UnpinAllForumTopicMessages,
    UnpinAllGeneralForumTopicMessages,
    UnpinChatMessage,
    UnRestrictChatMember,
    UploadStickerFile,
    UpgradeGift,
    Runner,
    VerifyChat,
    VerifyUser,
    RemoveUserVerification,
    RemoveChatVerification,
    RemoveBusinessAccountProfilePhoto,
    TransferBusinessAccountStars,
    TransferGift,
    PostStory,
):
    pass



import tgram
from typing import Union


class DeclineChatJoinRequest:
    async def decline_chat_join_request(
        self: "tgram.TgBot", chat_id: Union[int, str], user_id: int
    ) -> bool:
        """
        Use this method to decline a chat join request.
        The bot must be an administrator in the chat for this to work and must have
        the can_invite_users administrator right. Returns True on success.

        Telegram documentation: https://core.telegram.org/bots/api#declinechatjoinrequest

        :param chat_id: Unique identifier for the target chat or username of the target supergroup
            (in the format @supergroupusername)
        :type chat_id: :obj:`int` or :obj:`str`

        :param user_id: Unique identifier of the target user
        :type user_id: :obj:`int` or :obj:`str`

        :return: True on success.
        :rtype: :obj:`bool`
        """

        result = await self(
            "declineChatJoinRequest",
            chat_id=chat_id,
            user_id=user_id,
        )
        return result["result"]



import tgram
from .type_ import Type_

from typing import Optional


class TransactionPartnerChat(Type_):
    """
    Describes a transaction with a chat.

    Telegram documentation: https://core.telegram.org/bots/api#transactionpartnerchat

    :param type: Type of the transaction partner, always “chat”
    :type type: :obj:`str`

    :param chat: Information about the chat
    :type user: :class:`Chat`

    :param gift: Optional. The gift sent to the chat by the bot
    :type gift: :class:`Gift`

    :return: Instance of the class
    :rtype: :class:`TransactionPartnerChat`
    """

    def __init__(
        self,
        chat: "tgram.types.Chat" = None,
        gift: "tgram.types.Gift" = None,
        me: "tgram.TgBot" = None,
        json: "dict" = None,
    ):
        super().__init__(me=me, json=json)
        self.type = "chat"
        self.chat = chat
        self.gift = gift

    @staticmethod
    def _parse(
        me: "tgram.TgBot" = None, d: dict = None, force: bool = None
    ) -> Optional["tgram.types.TransactionPartnerChat"]:
        return (
            TransactionPartnerChat(
                me=me,
                json=d,
                type=d.get("type"),
                chat=tgram.types.Chat._parse(me=me, d=d.get("chat")),
                gift=tgram.types.Gift._parse(me=me, d=d.get("gift"))
                if d.get("gift")
                else None,
            )
            if d and (force or me and __class__.__name__ not in me._custom_types)
            else None
            if not d
            else Type_._custom_parse(
                __class__._parse(me=me, d=d, force=True),
                me._custom_types.get(__class__.__name__),
            )
        )



import tgram
from typing import Union


class UnbanChatMember:
    async def unban_chat_member(
        self: "tgram.TgBot",
        chat_id: Union[int, str],
        user_id: int,
        only_if_banned: bool = None,
    ) -> bool:
        """
        Use this method to unban a previously kicked user in a supergroup or channel.
        The user will not return to the group or channel automatically, but will be able to join via link, etc.
        The bot must be an administrator for this to work. By default, this method guarantees that after the call
        the user is not a member of the chat, but will be able to join it. So if the user is a member of the chat
        they will also be removed from the chat. If you don't want this, use the parameter only_if_banned.

        Telegram documentation: https://core.telegram.org/bots/api#unbanchatmember

        :param chat_id: Unique identifier for the target group or username of the target supergroup or channel
            (in the format @username)
        :type chat_id: :obj:`int` or :obj:`str`

        :param user_id: Unique identifier of the target user
        :type user_id: :obj:`int`

        :param only_if_banned: Do nothing if the user is not banned
        :type only_if_banned: :obj:`bool`

        :return: True on success
        :rtype: :obj:`bool`
        """

        result = await self(
            "unbanChatMember",
            chat_id=chat_id,
            user_id=user_id,
            only_if_banned=only_if_banned,
        )
        return result["result"]



import datetime
from typing import Union


class ReadableTime(datetime.datetime):
    def to_relative_time(self) -> str:
        """
        Converts the datetime object into a relative time string,
        indicating the difference between the current time and the object's time.

        Examples:
            - '5 minutes ago'
            - '2 months 3 days 4 hours 15 minutes left'
            - 'Just now'

        Returns:
            str: A human-readable string representing the time difference.
        """
        now = self.now()
        delta, prefix = (now - self, "ago") if now > self else (self - now, "left")

        seconds = delta.total_seconds()
        years = int(seconds // (365 * 24 * 60 * 60))
        seconds %= 365 * 24 * 60 * 60
        months = int(seconds // (30 * 24 * 60 * 60))
        seconds %= 30 * 24 * 60 * 60
        days = int(seconds // (24 * 60 * 60))
        seconds %= 24 * 60 * 60
        hours = int(seconds // 3600)
        seconds %= 3600
        minutes = int(seconds // 60)
        seconds = int(seconds % 60)

        time_parts = []
        if years > 0:
            time_parts.append(f"{years} year(s)")
        if months > 0:
            time_parts.append(f"{months} month(s)")
        if days > 0:
            time_parts.append(f"{days} day(s)")
        if hours > 0:
            time_parts.append(f"{hours} hour(s)")
        if minutes > 0:
            time_parts.append(f"{minutes} minute(s)")
        if seconds > 0:
            time_parts.append(f"{seconds} second(s)")

        # Join the parts together, or return "Just now" if empty
        return " ".join(time_parts) + f" {prefix}" if time_parts else "Just now"

    def to_formatted_time(self) -> str:
        """
        Converts the datetime object into a formatted string.

        Format:
            'YYYY/MM/DD - HH:MM:SS'

        Returns:
            str: A string representation of the datetime object in the specified format.
        """
        return self.strftime("%Y/%m/%d - %H:%M:%S")


def convert_timestamp(timestamp: Union[int, float]) -> ReadableTime:
    """
    Converts a Unix timestamp into a ReadableTime object.

    Parameters:
        timestamp (int | float): A Unix timestamp.

    Returns:
        ReadableTime: A datetime object with methods to get a human-readable time difference.
    """
    return ReadableTime.fromtimestamp(timestamp)



import tgram

from tgram.types import Gifts


class GetAvailableGifts:
    async def get_available_gifts(self: "tgram.TgBot") -> Gifts:
        """
        Returns the list of gifts that can be sent by the bot to users. Requires no parameters. Returns a Gifts object.

        Telegram documentation: https://core.telegram.org/bots/api#getavailablegifts
        """
        result = await self("getAvailableGifts")

        return Gifts._parse(self, result["result"])



import tgram
from typing import Union


class PinChatMessage:
    async def pin_chat_message(
        self: "tgram.TgBot",
        chat_id: Union[int, str],
        message_id: int,
        disable_notification: bool = None,
        business_connection_id: str = None,
    ) -> bool:
        """
        Use this method to pin a message in a supergroup.
        The bot must be an administrator in the chat for this to work and must have the appropriate admin rights.
        Returns True on success.

        Telegram documentation: https://core.telegram.org/bots/api#pinchatmessage

        :param chat_id: Unique identifier for the target chat or username of the target channel
            (in the format @channelusername)
        :type chat_id: :obj:`int` or :obj:`str`

        :param message_id: Identifier of a message to pin
        :type message_id: :obj:`int`

        :param disable_notification: Pass True, if it is not necessary to send a notification
            to all group members about the new pinned message
        :type disable_notification: :obj:`bool`

        :param business_connection_id: Unique identifier of the business connection on behalf of which the message will be pinned
        :type business_connection_id: :obj:`str`

        :return: True on success.
        :rtype: :obj:`bool`
        """

        result = await self(
            "pinChatMessage",
            chat_id=chat_id,
            message_id=message_id,
            disable_notification=disable_notification,
            business_connection_id=business_connection_id,
        )
        return result["result"]



import tgram
from .type_ import Type_

from typing import Optional
from tgram import bound


class ChatJoinRequest(Type_, bound.ChatJoinRequestB):
    """
    Represents a join request sent to a chat.

    Telegram Documentation: https://core.telegram.org/bots/api#chatjoinrequest

    :param chat: Chat to which the request was sent
    :type chat: :class:`tgram.types.Chat`

    :param from_user: User that sent the join request
    :type from_user: :class:`tgram.types.User`

    :param user_chat_id: Optional. Identifier of a private chat with the user who sent the join request.
        This number may have more than 32 significant bits and some programming languages may have difficulty/silent
        defects in interpreting it. But it has at most 52 significant bits, so a 64-bit integer or double-precision
        float type are safe for storing this identifier. The bot can use this identifier for 24 hours to send messages
        until the join request is processed, assuming no other administrator contacted the user.
    :type user_chat_id: :obj:`int`

    :param date: Date the request was sent in Unix time
    :type date: :obj:`int`

    :param bio: Optional. Bio of the user.
    :type bio: :obj:`str`

    :param invite_link: Optional. Chat invite link that was used by the user to send the join request
    :type invite_link: :class:`tgram.types.ChatInviteLink`

    :return: Instance of the class
    :rtype: :class:`tgram.types.ChatJoinRequest`
    """

    def __init__(
        self,
        chat: "tgram.types.Chat" = None,
        from_user: "tgram.types.User" = None,
        user_chat_id: "int" = None,
        date: "int" = None,
        bio: "str" = None,
        invite_link: "tgram.types.ChatInviteLink" = None,
        me: "tgram.TgBot" = None,
        json: "dict" = None,
    ):
        super().__init__(me=me, json=json)
        self.chat = chat
        self.from_user = from_user
        self.user_chat_id = user_chat_id
        self.date = date
        self.bio = bio
        self.invite_link = invite_link

    @staticmethod
    def _parse(
        me: "tgram.TgBot" = None, d: dict = None, force: bool = None
    ) -> Optional["tgram.types.ChatJoinRequest"]:
        return (
            ChatJoinRequest(
                me=me,
                json=d,
                chat=tgram.types.Chat._parse(me=me, d=d.get("chat")),
                from_user=tgram.types.User._parse(me=me, d=d.get("from")),
                user_chat_id=d.get("user_chat_id"),
                date=d.get("date"),
                bio=d.get("bio"),
                invite_link=tgram.types.ChatInviteLink._parse(
                    me=me, d=d.get("invite_link")
                ),
            )
            if d and (force or me and __class__.__name__ not in me._custom_types)
            else None
            if not d
            else Type_._custom_parse(
                __class__._parse(me=me, d=d, force=True),
                me._custom_types.get(__class__.__name__),
            )
        )



import tgram
from typing import Union
from tgram.types import ForumTopic


class CreateForumTopic:
    async def create_forum_topic(
        self: "tgram.TgBot",
        chat_id: Union[int, str],
        name: str,
        icon_color: int = None,
        icon_custom_emoji_id: str = None,
    ) -> ForumTopic:
        """
        Use this method to create a topic in a forum supergroup chat. The bot must be an administrator
        in the chat for this to work and must have the can_manage_topics administrator rights.
        Returns information about the created topic as a ForumTopic object.

        Telegram documentation: https://core.telegram.org/bots/api#createforumtopic

        :param chat_id: Unique identifier for the target chat or username of the target channel (in the format @channelusername)
        :type chat_id: :obj:`int` or :obj:`str`

        :param name: Name of the topic, 1-128 characters
        :type name: :obj:`str`

        :param icon_color: Color of the topic icon in RGB format. Currently, must be one of 0x6FB9F0, 0xFFD67E, 0xCB86DB, 0x8EEE98, 0xFF93B2, or 0xFB6F5F
        :type icon_color: :obj:`int`

        :param icon_custom_emoji_id: Custom emoji for the topic icon. Must be an emoji of type “tgs” and must be exactly 1 character long
        :type icon_custom_emoji_id: :obj:`str`

        :return: On success, information about the created topic is returned as a ForumTopic object.
        :rtype: :class:`tgram.types.ForumTopic`
        """

        result = await self(
            "createForumTopic",
            chat_id=chat_id,
            name=name,
            icon_color=icon_color,
            icon_custom_emoji_id=icon_custom_emoji_id,
        )
        return ForumTopic._parse(me=self, d=result["result"])



import tgram
from .type_ import Type_

from typing import Optional


class LoginUrl(Type_):
    """
    This object represents a parameter of the inline keyboard button used to automatically authorize a user. Serves as a great replacement for the Telegram Login Widget when the user is coming from Telegram. All the user needs to do is tap/click a button and confirm that they want to log in:

    Telegram Documentation: https://core.telegram.org/bots/api#loginurl

    :param url: An HTTPS URL to be opened with user authorization data added to the query string when the button is pressed.
        If the user refuses to provide authorization data, the original URL without information about the user will be
        opened. The data added is the same as described in Receiving authorization data. NOTE: You must always check the hash
        of the received data to verify the authentication and the integrity of the data as described in Checking
        authorization.
    :type url: :obj:`str`

    :param forward_text: Optional. New text of the button in forwarded messages.
    :type forward_text: :obj:`str`

    :param bot_username: Optional. Username of a bot, which will be used for user authorization. See Setting up a bot for
        more details. If not specified, the current bot's username will be assumed. The url's domain must be the same as the
        domain linked with the bot. See Linking your domain to the bot for more details.
    :type bot_username: :obj:`str`

    :param request_write_access: Optional. Pass True to request the permission for your bot to send messages to the
        user.
    :type request_write_access: :obj:`bool`

    :return: Instance of the class
    :rtype: :class:`tgram.types.LoginUrl`
    """

    def __init__(
        self,
        url: "str" = None,
        forward_text: "str" = None,
        bot_username: "str" = None,
        request_write_access: "bool" = None,
        me: "tgram.TgBot" = None,
        json: "dict" = None,
    ):
        super().__init__(me=me, json=json)
        self.url = url
        self.forward_text = forward_text
        self.bot_username = bot_username
        self.request_write_access = request_write_access

    @staticmethod
    def _parse(
        me: "tgram.TgBot" = None, d: dict = None, force: bool = None
    ) -> Optional["tgram.types.LoginUrl"]:
        return (
            LoginUrl(
                me=me,
                json=d,
                url=d.get("url"),
                forward_text=d.get("forward_text"),
                bot_username=d.get("bot_username"),
                request_write_access=d.get("request_write_access"),
            )
            if d and (force or me and __class__.__name__ not in me._custom_types)
            else None
            if not d
            else Type_._custom_parse(
                __class__._parse(me=me, d=d, force=True),
                me._custom_types.get(__class__.__name__),
            )
        )



import tgram
import random
from .type_ import Type_

from typing import Optional


class KeyboardButtonRequestUsers(Type_):
    """
    This object defines the criteria used to request a suitable user.
    The identifier of the selected user will be shared with the bot when the corresponding button is pressed.

    Telegram documentation: https://core.telegram.org/bots/api#keyboardbuttonrequestusers

    :param request_id: Signed 32-bit identifier of the request, which will be received back in the UsersShared object.
        Must be unique within the message
    :type request_id: :obj:`int`

    :param user_is_bot: Optional. Pass True to request a bot, pass False to request a regular user.
        If not specified, no additional restrictions are applied.
    :type user_is_bot: :obj:`bool`

    :param user_is_premium: Optional. Pass True to request a premium user, pass False to request a non-premium user.
        If not specified, no additional restrictions are applied.
    :type user_is_premium: :obj:`bool`

    :param max_quantity: Optional. The maximum number of users to be selected; 1-10. Defaults to 1.
    :type max_quantity: :obj:`int`

    :param request_name: Optional. Request name
    :type request_name: :obj:`bool`

    :param request_username: Optional. Request username
    :type request_username: :obj:`bool`

    :param request_photo: Optional. Request photo
    :type request_photo: :obj:`bool`

    :return: Instance of the class
    :rtype: :class:`tgram.types.KeyboardButtonRequestUsers`
    """

    def __init__(
        self,
        user_is_bot: "bool" = None,
        user_is_premium: "bool" = None,
        max_quantity: "int" = None,
        request_name: "bool" = None,
        request_username: "bool" = None,
        request_photo: "bool" = None,
        me: "tgram.TgBot" = None,
        json: "dict" = None,
    ):
        super().__init__(me=me, json=json)
        self.request_id = random.randint(10000, 99999)
        self.user_is_bot = user_is_bot
        self.user_is_premium = user_is_premium
        self.max_quantity = max_quantity
        self.request_name = request_name
        self.request_username = request_username
        self.request_photo = request_photo

    @staticmethod
    def _parse(
        me: "tgram.TgBot" = None, d: dict = None, force: bool = None
    ) -> Optional["tgram.types.KeyboardButtonRequestUsers"]:
        return (
            KeyboardButtonRequestUsers(
                me=me,
                json=d,
                user_is_bot=d.get("user_is_bot"),
                user_is_premium=d.get("user_is_premium"),
                max_quantity=d.get("max_quantity"),
                request_name=d.get("request_name"),
                request_username=d.get("request_username"),
                request_photo=d.get("request_photo"),
            )
            if d and (force or me and __class__.__name__ not in me._custom_types)
            else None
            if not d
            else Type_._custom_parse(
                __class__._parse(me=me, d=d, force=True),
                me._custom_types.get(__class__.__name__),
            )
        )



import tgram
from typing import List
from tgram.types import BotCommand
from tgram.types import BotCommandScope


class GetMyCommands:
    async def get_my_commands(
        self: "tgram.TgBot", scope: BotCommandScope = None, language_code: str = None
    ) -> List[BotCommand]:
        """
        Use this method to get the current list of the bot's commands.
        Returns List of BotCommand on success.

        Telegram documentation: https://core.telegram.org/bots/api#getmycommands

        :param scope: The scope of users for which the commands are relevant.
            Defaults to BotCommandScopeDefault.
        :type scope: :class:`tgram.types.BotCommandScope`

        :param language_code: A two-letter ISO 639-1 language code. If empty,
            commands will be applied to all users from the given scope,
            for whose language there are no dedicated commands
        :type language_code: :obj:`str`

        :return: List of BotCommand on success.
        :rtype: :obj:`list` of :class:`tgram.types.BotCommand`
        """

        result = await self(
            "getMyCommands",
            scope=scope,
            language_code=language_code,
        )
        return [BotCommand._parse(me=self, d=i) for i in result["result"]]



import tgram


class ReadBusinessMessage:
    async def read_business_message(
        self: "tgram.TgBot",
        business_connection_id: str,
        chat_id: int,
        message_id: int,
    ) -> bool:
        """
        Marks an incoming message as read on behalf of a business account.
        Requires the can_read_messages business bot right.

        Telegram documentation: https://core.telegram.org/bots/api#readbusinessmessage

        :param business_connection_id: Unique identifier of the business connection on behalf of which to read the message
        :type business_connection_id: :obj:`str`

        :param chat_id: Unique identifier of the chat in which the message was received. The chat must have been active in the last 24 hours.
        :type chat_id: :obj:`int`

        :param message_id: Unique identifier of the message to mark as read
        :type message_id: :obj:`int`

        :return: On success, returns True.
        :rtype: :obj:`bool`
        """

        result = await self(
            "readBusinessMessage",
            business_connection_id=business_connection_id,
            chat_id=chat_id,
            message_id=message_id,
        )
        return result["result"]



import tgram
from typing import Union


class DeleteChatPhoto:
    async def delete_chat_photo(self: "tgram.TgBot", chat_id: Union[int, str]) -> bool:
        """
        Use this method to delete a chat photo. Photos can't be changed for private chats.
        The bot must be an administrator in the chat for this to work and must have the appropriate admin rights.
        Returns True on success.
        Note: In regular groups (non-supergroups), this method will only work if the ‘All Members Are Admins’ setting is off in the target group.

        Telegram documentation: https://core.telegram.org/bots/api#deletechatphoto

        :param chat_id: Int or Str: Unique identifier for the target chat or username of the target channel
            (in the format @channelusername)
        :type chat_id: :obj:`int` or :obj:`str`

        :return: True on success.
        :rtype: :obj:`bool`
        """

        result = await self(
            "deleteChatPhoto",
            chat_id=chat_id,
        )
        return result["result"]



import tgram
from tgram.types import WebhookInfo


class GetWebhookInfo:
    async def get_webhook_info(self: "tgram.TgBot") -> WebhookInfo:
        """
        Use this method to get current webhook status. Requires no parameters.
        On success, returns a WebhookInfo object. If the bot is using getUpdates, will return an object with the url field empty.

        Telegram documentation: https://core.telegram.org/bots/api#getwebhookinfo

        :param timeout: Request connection timeout
        :type timeout: :obj:`int`, optional

        :return: On success, returns a WebhookInfo object.
        :rtype: :class:`tgram.types.WebhookInfo`
        """

        result = await self(
            "getWebhookInfo",
        )
        return WebhookInfo._parse(me=self, d=result["result"])



import tgram

from typing import Union, List
from tgram.utils import Mention


class ChatB:
    async def leave(
        self: Union["tgram.types.Chat", "tgram.types.ChatFullInfo"],
    ) -> bool:
        """
        Leave the chat.

        Returns:
            bool: True if the bot successfully left the chat, False otherwise.
        """
        return await self._me.leave_chat(self.id)

    async def ban_member(
        self: Union["tgram.types.Chat", "tgram.types.ChatFullInfo"],
        user_id: int,
        until_date: int = None,
        revoke_messages: bool = None,
    ) -> bool:
        """
        Ban a member from the chat.

        Args:
            user_id (int): The ID of the user to ban.
            until_date (int, optional): Date when the user will be unbanned, unix time.
            revoke_messages (bool, optional): Pass True to delete all messages from the chat for the user that is being removed.

        Returns:
            bool: True if the user was successfully banned, False otherwise.
        """
        return await self._me.ban_chat_member(
            self.id,
            user_id=user_id,
            until_date=until_date,
            revoke_messages=revoke_messages,
        )

    async def unban_member(
        self: Union["tgram.types.Chat", "tgram.types.ChatFullInfo"],
        user_id: int,
        only_if_banned: bool = None,
    ) -> bool:
        """
        Unban a previously banned member from the chat.

        Args:
            user_id (int): The ID of the user to unban.
            only_if_banned (bool, optional): Do nothing if the user is not banned.

        Returns:
            bool: True if the user was successfully unbanned, False otherwise.
        """
        return await self._me.unban_chat_member(
            self.id,
            user_id=user_id,
            only_if_banned=only_if_banned,
        )

    async def ban_sender_chat(
        self: Union["tgram.types.Chat", "tgram.types.ChatFullInfo"], sender_chat_id: int
    ) -> bool:
        """
        Ban a channel chat in a supergroup or a channel.

        Args:
            sender_chat_id (int): The ID of the sender chat to ban.

        Returns:
            bool: True if the sender chat was successfully banned, False otherwise.
        """
        return await self._me.ban_chat_sender_chat(
            self.id, sender_chat_id=sender_chat_id
        )

    async def unban_sender_chat(
        self: Union["tgram.types.Chat", "tgram.types.ChatFullInfo"], sender_chat_id: int
    ) -> bool:
        """
        Unban a previously banned channel chat in a supergroup or a channel.

        Args:
            sender_chat_id (int): The ID of the sender chat to unban.

        Returns:
            bool: True if the sender chat was successfully unbanned, False otherwise.
        """
        return await self._me.unban_chat_sender_chat(
            self.id, sender_chat_id=sender_chat_id
        )

    async def restrict_member(
        self: Union["tgram.types.Chat", "tgram.types.ChatFullInfo"],
        user_id: int,
        permissions: "tgram.types.ChatPermissions",
        use_independent_chat_permissions: bool = None,
        until_date: int = None,
    ) -> bool:
        """
        Restrict a member in the chat.

        Args:
            user_id (int): The ID of the user to restrict.
            permissions (tgram.types.ChatPermissions): New user permissions.
            use_independent_chat_permissions (bool, optional): Pass True if chat permissions are set independently.
            until_date (int, optional): Date when restrictions will be lifted for the user, unix time.

        Returns:
            bool: True if the user was successfully restricted, False otherwise.
        """
        return await self._me.restrict_chat_member(
            self.id,
            user_id=user_id,
            permissions=permissions,
            use_independent_chat_permissions=use_independent_chat_permissions,
            until_date=until_date,
        )

    async def unrestrict_member(
        self: Union["tgram.types.Chat", "tgram.types.ChatFullInfo"],
        user_id: int,
        use_independent_chat_permissions: bool = None,
    ) -> bool:
        """
        Unrestrict a previously restricted member in the chat.

        Args:
            user_id (int): The ID of the user to unrestrict.
            use_independent_chat_permissions (bool, optional): Pass True if chat permissions are set independently.

        Returns:
            bool: True if the user was successfully unrestricted, False otherwise.
        """
        return await self._me.unrestrict_chat_member(
            self.id,
            user_id=user_id,
            use_independent_chat_permissions=use_independent_chat_permissions,
        )

    async def mute(
        self: Union["tgram.types.Chat", "tgram.types.ChatFullInfo"], user_id: int
    ) -> bool:
        """
        Mute a member in the chat.

        Args:
            user_id (int): The ID of the user to mute.

        Returns:
            bool: True if the user was successfully muted, False otherwise.
        """
        if self._me.storage is None:
            raise ValueError("Please enable storage option in TgBot class.")

        return await self._me.storage.mute(self.id, user_id)

    async def unmute(
        self: Union["tgram.types.Chat", "tgram.types.ChatFullInfo"], user_id: int
    ) -> bool:
        """
        Unmute a previously muted member in the chat.

        Args:
            user_id (int): The ID of the user to unmute.

        Returns:
            bool: True if the user was successfully unmuted, False otherwise.
        """
        if self._me.storage is None:
            raise ValueError("Please enable storage option in TgBot class.")

        return await self._me.storage.unmute(self.id, user_id)

    async def get_muted_members(
        self: Union["tgram.types.Chat", "tgram.types.ChatFullInfo"],
    ) -> List[int]:
        """
        Get a list of muted members in the chat.

        Returns:
            List[int]: A list of user IDs who are muted in the chat.
        """
        if self._me.storage is None:
            raise ValueError("Please enable storage option in TgBot class.")

        mute_list = await self._me.storage.get_mute_list()

        return [user_id for chat_id, user_id in mute_list if chat_id is self.id]

    @property
    def mention(
        self: Union["tgram.types.Chat", "tgram.types.ChatFullInfo"],
        name: str = None,
    ) -> Mention:
        """
        Get a mention object for the chat.

        Args:
            name (str, optional): The name to use for the mention. Defaults to the chat's first name.

        Returns:
            Mention: A mention object for the chat.
        """
        if self.type != "private":
            raise ValueError(
                "You can't mention groups or channels, the chat instance must be user."
            )

        return Mention(name or self.first_name, self.id)

    @property
    def full_name(self: Union["tgram.types.Chat", "tgram.types.ChatFullInfo"]) -> str:
        """
        Get the full name of the chat.

        Returns:
            str: The full name of the chat.
        """
        if self.type != "private":
            raise ValueError(
                "You can't get full name of groups or channels, the chat instance must be user."
            )

        return (
            self.first_name
            if not self.last_name
            else f"{self.first_name} {self.last_name}"
        )



import tgram
from .type_ import Type_

from typing import Optional


class TransactionPartnerAffiliateProgram(Type_):
    """
    Describes the affiliate program that issued the affiliate commission received via this transaction.

    Telegram documentation: https://core.telegram.org/bots/api#transactionpartneraffiliateprogram

    :param type: Type of the transaction partner, always “affiliate_program”
    :type type: :obj:`str`

    :param sponsor_user: Optional. Information about the bot that sponsored the affiliate program
    :type sponsor_user: :class:`User`

    :param commission_per_mille: The number of Telegram Stars received by the bot for each 1000 Telegram Stars received by the affiliate program sponsor from referred users
    :type commission_per_mille: :obj:`int`

    :return: Instance of the class
    :rtype: :class:`TransactionPartnerAffiliateProgram`
    """

    def __init__(
        self,
        sponsor_user: "tgram.types.User" = None,
        commission_per_mille: int = None,
        me: "tgram.TgBot" = None,
        json: "dict" = None,
    ):
        super().__init__(me=me, json=json)
        self.type = "affiliate_program"
        self.sponsor_user = sponsor_user
        self.commission_per_mille = commission_per_mille

    @staticmethod
    def _parse(
        me: "tgram.TgBot" = None, d: dict = None, force: bool = None
    ) -> Optional["tgram.types.TransactionPartnerAffiliateProgram"]:
        return (
            TransactionPartnerAffiliateProgram(
                me=me,
                json=d,
                type=d.get("type"),
                sponsor_user=tgram.types.User._parse(me=me, d=d.get("sponsor_user")),
                commission_per_mille=d.get("commission_per_mille"),
            )
            if d and (force or me and __class__.__name__ not in me._custom_types)
            else None
            if not d
            else Type_._custom_parse(
                __class__._parse(me=me, d=d, force=True),
                me._custom_types.get(__class__.__name__),
            )
        )



import tgram

from typing import List, Optional
from .type_ import Type_


class ChecklistTasksDone(Type_):
    """
    Describes a service message about checklist tasks marked as done or not done.

    :param checklist_message: Optional. Message containing the checklist whose tasks were marked as done or not done. Note that the Message object in this field will not contain the reply_to_message field even if it itself is a reply.
    :type checklist_message: :class:`tgram.types.Message`

    :param marked_as_done_task_ids: Optional. Identifiers of the tasks that were marked as done
    :type marked_as_done_task_ids: :obj:`list` of :obj:`int`

    :param marked_as_not_done_task_ids: Optional. Identifiers of the tasks that were marked as not done
    :type marked_as_not_done_task_ids: :obj:`list` of :obj:`int`
    """

    def __init__(
        self,
        checklist_message: "tgram.types.Message" = None,
        marked_as_done_task_ids: List[int] = None,
        marked_as_not_done_task_ids: List[int] = None,
        me: "tgram.TgBot" = None,
        json: "dict" = None,
    ):
        super().__init__(me=me, json=json)
        self.checklist_message = checklist_message
        self.marked_as_done_task_ids = marked_as_done_task_ids
        self.marked_as_not_done_task_ids = marked_as_not_done_task_ids

    @staticmethod
    def _parse(
        me: "tgram.TgBot" = None, d: dict = None, force: bool = None
    ) -> Optional["ChecklistTasksDone"]:
        return (
            ChecklistTasksDone(
                me=me,
                json=d,
                checklist_message=tgram.types.Message._parse(
                    me=me, d=d.get("checklist_message")
                ),
                marked_as_done_task_ids=d.get("marked_as_done_task_ids"),
                marked_as_not_done_task_ids=d.get("marked_as_not_done_task_ids"),
            )
            if d and (force or me and __class__.__name__ not in me._custom_types)
            else None
            if not d
            else Type_._custom_parse(
                __class__._parse(me=me, d=d, force=True),
                me._custom_types.get(__class__.__name__),
            )
        )



import tgram

from .type_ import Type_
from typing import Optional


class LocationAddress(Type_):
    """
    Describes the physical address of a location.

    :param country_code: The two-letter ISO 3166-1 alpha-2 country code of the country where the location is located
    :type country_code: :obj:`str`
    :param state: Optional. State of the location
    :type state: :obj:`str`
    :param city: Optional. City of the location
    :type city: :obj:`str`
    :param street: Optional. Street address of the location
    :type street: :obj:`str`
    """

    def __init__(
        self,
        country_code: str = None,
        state: str = None,
        city: str = None,
        street: str = None,
        me: "tgram.TgBot" = None,
        json: dict = None,
    ):
        super().__init__(me=me, json=json)
        self.country_code = country_code
        self.state = state
        self.city = city
        self.street = street

    @staticmethod
    def _parse(
        me: "tgram.TgBot" = None, d: dict = None, force: bool = None
    ) -> Optional["LocationAddress"]:
        return (
            LocationAddress(
                country_code=d.get("country_code"),
                state=d.get("state"),
                city=d.get("city"),
                street=d.get("street"),
            )
            if d and (force or me and __class__.__name__ not in me._custom_types)
            else None
            if not d
            else Type_._custom_parse(
                __class__._parse(me=me, d=d, force=True),
                me._custom_types.get(__class__.__name__),
            )
        )



import tgram
from typing import Union
from tgram.types import ChatMember
from tgram.types import ChatMemberAdministrator
from tgram.types import ChatMemberBanned
from tgram.types import ChatMemberLeft
from tgram.types import ChatMemberMember
from tgram.types import ChatMemberOwner
from tgram.types import ChatMemberRestricted


class GetChatMember:
    async def get_chat_member(
        self: "tgram.TgBot", chat_id: Union[int, str], user_id: int
    ) -> Union[
        ChatMemberOwner,
        ChatMemberAdministrator,
        ChatMemberMember,
        ChatMemberRestricted,
        ChatMemberBanned,
        ChatMemberLeft,
    ]:
        result = await self(
            "getChatMember",
            chat_id=chat_id,
            user_id=user_id,
        )
        return ChatMember._parse(me=self, d=result["result"])



import tgram
from typing import Union
from pathlib import Path


class SetChatPhoto:
    async def set_chat_photo(
        self: "tgram.TgBot", chat_id: Union[int, str], photo: Union[Path, bytes, str]
    ) -> bool:
        """
        Use this method to set a new profile photo for the chat. Photos can't be changed for private chats.
        The bot must be an administrator in the chat for this to work and must have the appropriate admin rights.
        Returns True on success.
        Note: In regular groups (non-supergroups), this method will only work if the ‘All Members Are Admins’
        setting is off in the target group.

        Telegram documentation: https://core.telegram.org/bots/api#setchatphoto

        :param chat_id: Int or Str: Unique identifier for the target chat or username of the target channel
            (in the format @channelusername)
        :type chat_id: :obj:`int` or :obj:`str`

        :param photo: InputFile: New chat photo, uploaded using multipart/form-data
        :type photo: :obj:`typing.Union[file_like, str]`
        :return: True on success.
        :rtype: :obj:`bool`
        """

        result = await self(
            "setChatPhoto",
            chat_id=chat_id,
            photo=photo,
        )
        return result["result"]



import tgram
from .type_ import Type_

from typing import List, Optional
from tgram import utils


class MessageReactionUpdated(Type_):
    """
    This object represents a service message about a change in the list of the current user's reactions to a message.

    Telegram documentation: https://core.telegram.org/bots/api#messagereactionupdated

    :param chat: The chat containing the message the user reacted to
    :type chat: :class:`tgram.types.Chat`

    :param message_id: Unique identifier of the message inside the chat
    :type message_id: :obj:`int`

    :param user: Optional. The user that changed the reaction, if the user isn't anonymous
    :type user: :class:`tgram.types.User`

    :param actor_chat: Optional. The chat on behalf of which the reaction was changed, if the user is anonymous
    :type actor_chat: :class:`tgram.types.Chat`

    :param date: Date of the change in Unix time
    :type date: :obj:`int`

    :param old_reaction: Previous list of reaction types that were set by the user
    :type old_reaction: :obj:`list` of :class:`ReactionType`

    :param new_reaction: New list of reaction types that have been set by the user
    :type new_reaction: :obj:`list` of :class:`ReactionType`

    :return: Instance of the class
    :rtype: :class:`MessageReactionUpdated`
    """

    def __init__(
        self,
        chat: "tgram.types.Chat" = None,
        message_id: "int" = None,
        date: "int" = None,
        old_reaction: List["tgram.types.ReactionType"] = None,
        new_reaction: List["tgram.types.ReactionType"] = None,
        user: "tgram.types.User" = None,
        actor_chat: "tgram.types.Chat" = None,
        me: "tgram.TgBot" = None,
        json: "dict" = None,
    ):
        super().__init__(me=me, json=json)
        self.chat = chat
        self.message_id = message_id
        self.user = user
        self.actor_chat = actor_chat
        self.date = date
        self.old_reaction = old_reaction
        self.new_reaction = new_reaction

    @staticmethod
    def _parse(
        me: "tgram.TgBot" = None, d: dict = None, force: bool = None
    ) -> Optional["tgram.types.MessageReactionUpdated"]:
        return (
            MessageReactionUpdated(
                me=me,
                json=d,
                chat=tgram.types.Chat._parse(me=me, d=d.get("chat")),
                message_id=d.get("message_id"),
                date=d.get("date"),
                old_reaction=utils.reaction_type_parse(me, d.get("old_reaction")),
                new_reaction=utils.reaction_type_parse(me, d.get("new_reaction")),
                user=tgram.types.User._parse(me=me, d=d.get("user")),
                actor_chat=tgram.types.Chat._parse(me=me, d=d.get("actor_chat")),
            )
            if d and (force or me and __class__.__name__ not in me._custom_types)
            else None
            if not d
            else Type_._custom_parse(
                __class__._parse(me=me, d=d, force=True),
                me._custom_types.get(__class__.__name__),
            )
        )



import tgram
from .type_ import Type_

from typing import Optional


class PreparedInlineMessage(Type_):
    """
    Describes an inline message to be sent by a user of a Mini App.

    Telegram Documentation: https://core.telegram.org/bots/api#preparedinlinemessage

    :param id: Unique identifier of the prepared message
    :type id: :obj:`str`

    :param expiration_date: Expiration date of the prepared message, in Unix time.
    Expired prepared messages can no longer be used
    :type expiration_date: :obj:`int`

    :return: Instance of the class
    :rtype: :class:`tgram.types.PreparedInlineMessage`
    """

    def __init__(
        self,
        id: "str" = None,
        expiration_date: "int" = None,
        me: "tgram.TgBot" = None,
        json: "dict" = None,
    ):
        super().__init__(me=me, json=json)
        self.id = id
        self.expiration_date = expiration_date

    @staticmethod
    def _parse(
        me: "tgram.TgBot" = None, d: dict = None, force: bool = None
    ) -> Optional["tgram.types.PreparedInlineMessage"]:
        return (
            PreparedInlineMessage(
                me=me,
                json=d,
                id=d.get("id"),
                expiration_date=d.get("expiration_date"),
            )
            if d and (force or me and __class__.__name__ not in me._custom_types)
            else None
            if not d
            else Type_._custom_parse(
                __class__._parse(me=me, d=d, force=True),
                me._custom_types.get(__class__.__name__),
            )
        )



import tgram
from .type_ import Type_

from typing import Optional


class MenuButtonWebApp(Type_):
    """
    Represents a menu button, which launches a Web App.

    Telegram Documentation: https://core.telegram.org/bots/api#menubuttonwebapp

    :param type: Type of the button, must be web_app
    :type type: :obj:`str`

    :param text: Text on the button
    :type text: :obj:`str`

    :param web_app: Description of the Web App that will be launched when the user presses the button. The Web App will be
        able to send an arbitrary message on behalf of the user using the method answerWebAppQuery.
    :type web_app: :class:`tgram.types.WebAppInfo`

    :return: Instance of the class
    :rtype: :class:`tgram.types.MenuButtonWebApp`
    """

    def __init__(
        self,
        type: "str" = None,
        text: "str" = None,
        web_app: "tgram.types.WebAppInfo" = None,
        me: "tgram.TgBot" = None,
        json: "dict" = None,
    ):
        super().__init__(me=me, json=json)
        self.type = type
        self.text = text
        self.web_app = web_app

    @staticmethod
    def _parse(
        me: "tgram.TgBot" = None, d: dict = None, force: bool = None
    ) -> Optional["tgram.types.MenuButtonWebApp"]:
        return (
            MenuButtonWebApp(
                me=me,
                json=d,
                type=d.get("type"),
                text=d.get("text"),
                web_app=tgram.types.WebAppInfo._parse(me=me, d=d.get("web_app")),
            )
            if d and (force or me and __class__.__name__ not in me._custom_types)
            else None
            if not d
            else Type_._custom_parse(
                __class__._parse(me=me, d=d, force=True),
                me._custom_types.get(__class__.__name__),
            )
        )



import tgram
from .type_ import Type_

from typing import Optional


class MessageAutoDeleteTimerChanged(Type_):
    """
    This object represents a service message about a change in auto-delete timer settings.

    Telegram Documentation: https://core.telegram.org/bots/api#messageautodeletetimerchanged

    :param message_auto_delete_time: New auto-delete time for messages in the chat; in seconds
    :type message_auto_delete_time: :obj:`int`

    :return: Instance of the class
    :rtype: :class:`tgram.types.MessageAutoDeleteTimerChanged`
    """

    def __init__(
        self,
        message_auto_delete_time: "int" = None,
        me: "tgram.TgBot" = None,
        json: "dict" = None,
    ):
        super().__init__(me=me, json=json)
        self.message_auto_delete_time = message_auto_delete_time

    @staticmethod
    def _parse(
        me: "tgram.TgBot" = None, d: dict = None, force: bool = None
    ) -> Optional["tgram.types.MessageAutoDeleteTimerChanged"]:
        return (
            MessageAutoDeleteTimerChanged(
                me=me,
                json=d,
                message_auto_delete_time=d.get("message_auto_delete_time"),
            )
            if d and (force or me and __class__.__name__ not in me._custom_types)
            else None
            if not d
            else Type_._custom_parse(
                __class__._parse(me=me, d=d, force=True),
                me._custom_types.get(__class__.__name__),
            )
        )



import tgram
from .type_ import Type_

from typing import List, Optional


class ShippingOption(Type_):
    """
    This object represents one shipping option.

    Telegram Documentation: https://core.telegram.org/bots/api#shippingoption

    :param id: Shipping option identifier
    :type id: :obj:`str`

    :param title: Option title
    :type title: :obj:`str`

    :param prices: List of price portions
    :type prices: :obj:`list` of :class:`tgram.types.LabeledPrice`

    :return: Instance of the class
    :rtype: :class:`tgram.types.ShippingOption`
    """

    def __init__(
        self,
        id: "str" = None,
        title: "str" = None,
        prices: List["tgram.types.LabeledPrice"] = None,
        me: "tgram.TgBot" = None,
        json: "dict" = None,
    ):
        super().__init__(me=me, json=json)
        self.id = id
        self.title = title
        self.prices = prices

    @staticmethod
    def _parse(
        me: "tgram.TgBot" = None, d: dict = None, force: bool = None
    ) -> Optional["tgram.types.ShippingOption"]:
        return (
            ShippingOption(
                me=me,
                json=d,
                id=d.get("id"),
                title=d.get("title"),
                prices=[
                    tgram.types.LabeledPrice._parse(me=me, d=i) for i in d.get("prices")
                ]
                if d.get("prices")
                else None,
            )
            if d and (force or me and __class__.__name__ not in me._custom_types)
            else None
            if not d
            else Type_._custom_parse(
                __class__._parse(me=me, d=d, force=True),
                me._custom_types.get(__class__.__name__),
            )
        )



from pathlib import Path as _Path
from typing import Union as _Union, Literal as _Literal
from io import BytesIO as _BytesIo

from ._accepted_gift_types import AcceptedGiftTypes
from ._affiliate_info import AffiliateInfo
from ._animation import Animation
from ._audio import Audio
from ._background_fill import BackgroundFill
from ._background_fill_freeform_gradient import BackgroundFillFreeformGradient
from ._background_fill_gradient import BackgroundFillGradient
from ._background_fill_solid import BackgroundFillSolid
from ._background_type import BackgroundType
from ._background_type_chat_theme import BackgroundTypeChatTheme
from ._background_type_fill import BackgroundTypeFill
from ._background_type_pattern import BackgroundTypePattern
from ._background_type_wallpaper import BackgroundTypeWallpaper
from ._birthdate import Birthdate
from ._bot_command import BotCommand
from ._bot_command_scope import BotCommandScope
from ._bot_command_scope_all_chat_administrators import (
    BotCommandScopeAllChatAdministrators,
)
from ._bot_command_scope_all_group_chats import BotCommandScopeAllGroupChats
from ._bot_command_scope_all_private_chats import BotCommandScopeAllPrivateChats
from ._bot_command_scope_chat import BotCommandScopeChat
from ._bot_command_scope_chat_administrators import BotCommandScopeChatAdministrators
from ._bot_command_scope_chat_member import BotCommandScopeChatMember
from ._bot_command_scope_default import BotCommandScopeDefault
from ._bot_description import BotDescription
from ._bot_name import BotName
from ._bot_short_description import BotShortDescription
from ._business_connection import BusinessConnection
from ._business_intro import BusinessIntro
from ._business_location import BusinessLocation
from ._business_messages_deleted import BusinessMessagesDeleted
from ._business_opening_hours import BusinessOpeningHours
from ._business_opening_hours_interval import BusinessOpeningHoursInterval
from ._callback_game import CallbackGame
from ._callback_query import CallbackQuery
from ._chat import Chat
from ._chat_administrator_rights import ChatAdministratorRights
from ._chat_background import ChatBackground
from ._chat_boost import ChatBoost
from ._chat_boost_added import ChatBoostAdded
from ._chat_boost_removed import ChatBoostRemoved
from ._chat_boost_source import ChatBoostSource
from ._chat_boost_source_gift_code import ChatBoostSourceGiftCode
from ._chat_boost_source_giveaway import ChatBoostSourceGiveaway
from ._chat_boost_source_premium import ChatBoostSourcePremium
from ._chat_boost_updated import ChatBoostUpdated
from ._chat_full_info import ChatFullInfo
from ._chat_invite_link import ChatInviteLink
from ._chat_join_request import ChatJoinRequest
from ._chat_location import ChatLocation
from ._chat_member import ChatMember
from ._chat_member_administrator import ChatMemberAdministrator
from ._chat_member_banned import ChatMemberBanned
from ._chat_member_left import ChatMemberLeft
from ._chat_member_member import ChatMemberMember
from ._chat_member_owner import ChatMemberOwner
from ._chat_member_restricted import ChatMemberRestricted
from ._chat_member_updated import ChatMemberUpdated
from ._chat_permissions import ChatPermissions
from ._chat_photo import ChatPhoto
from ._chat_shared import ChatShared
from ._chosen_inline_result import ChosenInlineResult
from ._contact import Contact
from ._copy_text_button import CopyTextButton
from ._check_list_task import ChecklistTask
from ._check_list import Checklist
from ._checklist_tasks_done import ChecklistTasksDone
from ._check_list_tasks_added import ChecklistTasksAdded
from ._dice import Dice
from ._document import Document
from ._direct_message_price_changed import DirectMessagePriceChanged
from ._encrypted_credentials import EncryptedCredentials
from ._encrypted_passport_element import EncryptedPassportElement
from ._external_reply_info import ExternalReplyInfo
from ._file import File
from ._force_reply import ForceReply
from ._forum_topic import ForumTopic
from ._forum_topic_closed import ForumTopicClosed
from ._forum_topic_created import ForumTopicCreated
from ._forum_topic_edited import ForumTopicEdited
from ._forum_topic_reopened import ForumTopicReopened
from ._game import Game
from ._game_high_score import GameHighScore
from ._general_forum_topic_hidden import GeneralForumTopicHidden
from ._general_forum_topic_unhidden import GeneralForumTopicUnhidden
from ._gifts import Gifts
from ._gift import Gift
from ._gift_info import GiftInfo
from ._giveaway import Giveaway
from ._giveaway_completed import GiveawayCompleted
from ._giveaway_created import GiveawayCreated
from ._giveaway_winners import GiveawayWinners
from ._inaccessible_message import InaccessibleMessage
from ._inline_keyboard_button import InlineKeyboardButton
from ._inline_keyboard_markup import InlineKeyboardMarkup
from ._inline_query import InlineQuery
from ._inline_query_result_article import InlineQueryResultArticle
from ._inline_query_result_audio import InlineQueryResultAudio
from ._inline_query_result_cached_audio import InlineQueryResultCachedAudio
from ._inline_query_result_cached_document import InlineQueryResultCachedDocument
from ._inline_query_result_cached_gif import InlineQueryResultCachedGif
from ._inline_query_result_cached_mpeg4_gif import InlineQueryResultCachedMpeg4Gif
from ._inline_query_result_cached_photo import InlineQueryResultCachedPhoto
from ._inline_query_result_cached_sticker import InlineQueryResultCachedSticker
from ._inline_query_result_cached_video import InlineQueryResultCachedVideo
from ._inline_query_result_cached_voice import InlineQueryResultCachedVoice
from ._inline_query_result_contact import InlineQueryResultContact
from ._inline_query_result_document import InlineQueryResultDocument
from ._inline_query_result_game import InlineQueryResultGame
from ._inline_query_result_gif import InlineQueryResultGif
from ._inline_query_result_location import InlineQueryResultLocation
from ._inline_query_result_mpeg4_gif import InlineQueryResultMpeg4Gif
from ._inline_query_result_photo import InlineQueryResultPhoto
from ._inline_query_result_venue import InlineQueryResultVenue
from ._inline_query_result_video import InlineQueryResultVideo
from ._inline_query_result_voice import InlineQueryResultVoice
from ._inline_query_results_button import InlineQueryResultsButton
from ._input_contact_message_content import InputContactMessageContent
from ._input_invoice_message_content import InputInvoiceMessageContent
from ._input_location_message_content import InputLocationMessageContent
from ._input_media_animation import InputMediaAnimation
from ._input_media_audio import InputMediaAudio
from ._input_media_document import InputMediaDocument
from ._input_media_photo import InputMediaPhoto
from ._input_media_video import InputMediaVideo
from ._input_message_content import InputMessageContent
from ._input_paid_media_photo import InputPaidMediaPhoto
from ._input_paid_media_video import InputPaidMediaVideo
from ._input_profile_photo import InputProfilePhotoStatic, InputProfilePhotoAnimated
from ._input_poll_option import InputPollOption
from ._input_sticker import InputSticker
from ._input_text_message_content import InputTextMessageContent
from ._input_venue_message_content import InputVenueMessageContent
from ._input_story_content import InputStoryContentPhoto, InputStoryContentVideo
from ._input_checklist_task import InputChecklistTask
from ._input_checklist import InputChecklist
from ._invoice import Invoice
from ._keyboard_button import KeyboardButton
from ._keyboard_button_poll_type import KeyboardButtonPollType
from ._keyboard_button_request_chat import KeyboardButtonRequestChat
from ._keyboard_button_request_users import KeyboardButtonRequestUsers
from ._labeled_price import LabeledPrice
from ._link_preview_options import LinkPreviewOptions
from ._listener import Listener
from ._location import Location
from ._login_url import LoginUrl
from ._location_address import LocationAddress
from ._mask_position import MaskPosition
from ._menu_button import MenuButton
from ._menu_button_commands import MenuButtonCommands
from ._menu_button_default import MenuButtonDefault
from ._menu_button_web_app import MenuButtonWebApp
from ._message import Message
from ._message_auto_delete_timer_changed import MessageAutoDeleteTimerChanged
from ._message_entity import MessageEntity
from ._message_id import MessageId
from ._message_origin_channel import MessageOriginChannel
from ._message_origin_chat import MessageOriginChat
from ._message_origin_hidden_user import MessageOriginHiddenUser
from ._message_origin_user import MessageOriginUser
from ._message_reaction_count_updated import MessageReactionCountUpdated
from ._message_reaction_updated import MessageReactionUpdated
from ._order_info import OrderInfo
from ._paid_media_info import PaidMediaInfo
from ._paid_media_photo import PaidMediaPhoto
from ._paid_media_preview import PaidMediaPreview
from ._paid_media_purchased import PaidMediaPurchased
from ._paid_media_video import PaidMediaVideo
from ._passport_data import PassportData
from ._passport_element_error import PassportElementError
from ._passport_element_error_data_field import PassportElementErrorDataField
from ._passport_element_error_file import PassportElementErrorFile
from ._passport_element_error_files import PassportElementErrorFiles
from ._passport_element_error_front_side import PassportElementErrorFrontSide
from ._passport_element_error_reverse_side import PassportElementErrorReverseSide
from ._passport_element_error_selfie import PassportElementErrorSelfie
from ._passport_element_error_translation_file import (
    PassportElementErrorTranslationFile,
)
from ._passport_element_error_translation_files import (
    PassportElementErrorTranslationFiles,
)
from ._passport_element_error_unspecified import PassportElementErrorUnspecified
from ._passport_file import PassportFile
from ._photo_size import PhotoSize
from ._poll import Poll
from ._poll_answer import PollAnswer
from ._poll_option import PollOption
from ._pre_checkout_query import PreCheckoutQuery
from ._prepared_inline_message import PreparedInlineMessage
from ._proximity_alert_triggered import ProximityAlertTriggered
from ._paid_message_price_changed import PaidMessagePriceChanged
from ._reaction_count import ReactionCount
from ._reaction_type_custom_emoji import ReactionTypeCustomEmoji
from ._reaction_type_emoji import ReactionTypeEmoji
from ._reaction_type_paid import ReactionTypePaid
from ._refunded_payment import RefundedPayment
from ._reply_keyboard_markup import ReplyKeyboardMarkup
from ._reply_keyboard_remove import ReplyKeyboardRemove
from ._reply_parameters import ReplyParameters
from ._response_parameters import ResponseParameters
from ._revenue_withdrawal_state_failed import RevenueWithdrawalStateFailed
from ._revenue_withdrawal_state_pending import RevenueWithdrawalStatePending
from ._revenue_withdrawal_state_succeeded import RevenueWithdrawalStateSucceeded
from ._sent_web_app_message import SentWebAppMessage
from ._shared_user import SharedUser
from ._shipping_address import ShippingAddress
from ._shipping_option import ShippingOption
from ._shipping_query import ShippingQuery
from ._star_transaction import StarTransaction
from ._star_transactions import StarTransactions
from ._star_amount import StarAmount
from ._sticker import Sticker
from ._sticker_set import StickerSet
from ._story import Story
from ._story_area import (
    StoryArea,
    StoryAreaPosition,
    StoryAreaTypeLink,
    StoryAreaTypeLocation,
    StoryAreaTypeSuggestedReaction,
    StoryAreaTypeUniqueGift,
    StoryAreaTypeWeather,
)
from ._successful_payment import SuccessfulPayment
from ._switch_inline_query_chosen_chat import SwitchInlineQueryChosenChat
from ._text_quote import TextQuote
from ._transaction_partner_affiliate_program import TransactionPartnerAffiliateProgram
from ._transaction_partner_chat import TransactionPartnerChat
from ._transaction_partner_fragment import TransactionPartnerFragment
from ._transaction_partner_other import TransactionPartnerOther
from ._transaction_partner_telegram_api import TransactionPartnerTelegramApi
from ._transaction_partner_telegram_ads import TransactionPartnerTelegramAds
from ._transaction_partner_user import TransactionPartnerUser
from ._update import Update
from ._user import User
from ._user_chat_boosts import UserChatBoosts
from ._user_profile_photos import UserProfilePhotos
from ._users_shared import UsersShared
from ._unique_gifts import (
    UniqueGift,
    UniqueGiftBackdrop,
    UniqueGiftBackdropColors,
    UniqueGiftInfo,
    UniqueGiftModel,
    UniqueGiftSymbol,
)
from ._owned_gifts import OwnedGifts, OwnedGiftRegular, OwnedGiftUnique
from ._venue import Venue
from ._video import Video
from ._video_chat_ended import VideoChatEnded
from ._video_chat_participants_invited import VideoChatParticipantsInvited
from ._video_chat_scheduled import VideoChatScheduled
from ._video_chat_started import VideoChatStarted
from ._video_note import VideoNote
from ._voice import Voice
from ._web_app_data import WebAppData
from ._web_app_info import WebAppInfo
from ._webhook_info import WebhookInfo
from ._write_access_allowed import WriteAccessAllowed

InlineQueryResult = _Union[
    "InlineQueryResultCachedAudio",
    "InlineQueryResultCachedDocument",
    "InlineQueryResultCachedGif",
    "InlineQueryResultCachedMpeg4Gif",
    "InlineQueryResultCachedPhoto",
    "InlineQueryResultCachedSticker",
    "InlineQueryResultCachedVideo",
    "InlineQueryResultCachedVoice",
    "InlineQueryResultArticle",
    "InlineQueryResultAudio",
    "InlineQueryResultContact",
    "InlineQueryResultGame",
    "InlineQueryResultDocument",
    "InlineQueryResultGif",
    "InlineQueryResultLocation",
    "InlineQueryResultMpeg4Gif",
    "InlineQueryResultPhoto",
    "InlineQueryResultVenue",
    "InlineQueryResultVideo",
    "InlineQueryResultVoice",
]

InputFile = _Union["bytes", "_Path", "str", "_BytesIo"]

InputMedia = _Union[
    "InputMediaAudio", "InputMediaDocument", "InputMediaPhoto", "InputMediaVideo"
]

InputPaidMedia = _Union["InputPaidMediaPhoto", "InputPaidMediaVideo"]

MaybeInaccessibleMessage = _Union["InaccessibleMessage", "Message"]

MessageOrigin = _Union[
    "MessageOriginUser",
    "MessageOriginHiddenUser",
    "MessageOriginChat",
    "MessageOriginChannel",
]

PaidMedia = _Union["PaidMediaPreview", "PaidMediaPhoto", "PaidMediaVideo"]

ReactionType = _Union[
    "ReactionTypeCustomEmoji", "ReactionTypeEmoji", "ReactionTypePaid"
]

RevenueWithdrawalState = _Union[
    "RevenueWithdrawalStatePending",
    "RevenueWithdrawalStateSucceeded",
    "RevenueWithdrawalStateFailed",
]

TransactionPartner = _Union[
    "TransactionPartnerFragment",
    "TransactionPartnerUser",
    "TransactionPartnerOther",
    "TransactionPartnerTelegramAds",
    "TransactionPartnerAffiliateProgram",
    "TransactionPartnerChat",
]

ParseMode = _Literal["Markdown", "MarkdownV2", "HTML", "Disable"]
ChatType = _Literal["private", "group", "supergroup", "channel"]
ChatMemberStatus = _Literal[
    "creator", "administrator", "member", "restricted", "left", "kicked"
]
MessageEntityType = _Literal[
    "mention",
    "hashtag",
    "cashtag",
    "bot_command",
    "url",
    "email",
    "phone_number",
    "bold",
    "italic",
    "underline",
    "strikethrough",
    "spoiler",
    "blockquote",
    "expandable_blockquote",
    "code",
    "pre",
    "text_link",
    "text_mention",
    "custom_emoji",
]

InputStoryContent = _Union["InputStoryContentPhoto", "InputStoryContentVideo"]

StoryAreaType = _Union[
    "StoryAreaTypeLink",
    "StoryAreaTypeLocation",
    "StoryAreaTypeSuggestedReaction",
    "StoryAreaTypeUniqueGift",
    "StoryAreaTypeWeather",
]

__all__ = [
    "AcceptedGiftTypes",
    "AffiliateInfo",
    "Animation",
    "Audio",
    "BackgroundFill",
    "BackgroundFillFreeformGradient",
    "BackgroundFillGradient",
    "BackgroundFillSolid",
    "BackgroundType",
    "BackgroundTypeChatTheme",
    "BackgroundTypeFill",
    "BackgroundTypePattern",
    "BackgroundTypeWallpaper",
    "Birthdate",
    "BotCommand",
    "BotCommandScope",
    "BotCommandScopeAllChatAdministrators",
    "BotCommandScopeAllGroupChats",
    "BotCommandScopeAllPrivateChats",
    "BotCommandScopeChat",
    "BotCommandScopeChatAdministrators",
    "BotCommandScopeChatMember",
    "BotCommandScopeDefault",
    "BotDescription",
    "BotName",
    "BotShortDescription",
    "BusinessConnection",
    "BusinessIntro",
    "BusinessLocation",
    "BusinessMessagesDeleted",
    "BusinessOpeningHours",
    "BusinessOpeningHoursInterval",
    "CallbackGame",
    "CallbackQuery",
    "Chat",
    "ChatAdministratorRights",
    "ChatBackground",
    "ChatBoost",
    "ChatBoostAdded",
    "ChatBoostRemoved",
    "ChatBoostSource",
    "ChatBoostSourceGiftCode",
    "ChatBoostSourceGiveaway",
    "ChatBoostSourcePremium",
    "ChatBoostUpdated",
    "ChatFullInfo",
    "ChatInviteLink",
    "ChatJoinRequest",
    "ChatLocation",
    "ChatMember",
    "ChatMemberAdministrator",
    "ChatMemberBanned",
    "ChatMemberLeft",
    "ChatMemberMember",
    "ChatMemberOwner",
    "ChatMemberRestricted",
    "ChatMemberUpdated",
    "ChatPermissions",
    "ChatPhoto",
    "ChatShared",
    "ChosenInlineResult",
    "Contact",
    "CopyTextButton",
    "ChecklistTask",
    "Checklist",
    "ChecklistTasksDone",
    "ChecklistTasksAdded",
    "Dice",
    "Document",
    "DirectMessagePriceChanged",
    "EncryptedCredentials",
    "EncryptedPassportElement",
    "ExternalReplyInfo",
    "File",
    "ForceReply",
    "ForumTopic",
    "ForumTopicClosed",
    "ForumTopicCreated",
    "ForumTopicEdited",
    "ForumTopicReopened",
    "Game",
    "GameHighScore",
    "GeneralForumTopicHidden",
    "GeneralForumTopicUnhidden",
    "Giveaway",
    "GiveawayCompleted",
    "GiveawayCreated",
    "GiveawayWinners",
    "GiftInfo",
    "InaccessibleMessage",
    "InlineKeyboardButton",
    "InlineKeyboardMarkup",
    "InlineQuery",
    "InlineQueryResult",
    "InlineQueryResultArticle",
    "InlineQueryResultAudio",
    "InlineQueryResultCachedAudio",
    "InlineQueryResultCachedDocument",
    "InlineQueryResultCachedGif",
    "InlineQueryResultCachedMpeg4Gif",
    "InlineQueryResultCachedPhoto",
    "InlineQueryResultCachedSticker",
    "InlineQueryResultCachedVideo",
    "InlineQueryResultCachedVoice",
    "InlineQueryResultContact",
    "InlineQueryResultDocument",
    "InlineQueryResultGame",
    "InlineQueryResultGif",
    "InlineQueryResultLocation",
    "InlineQueryResultMpeg4Gif",
    "InlineQueryResultPhoto",
    "InlineQueryResultVenue",
    "InlineQueryResultVideo",
    "InlineQueryResultVoice",
    "InlineQueryResultsButton",
    "InputContactMessageContent",
    "InputFile",
    "InputInvoiceMessageContent",
    "InputLocationMessageContent",
    "InputMedia",
    "InputMediaAnimation",
    "InputMediaAudio",
    "InputMediaDocument",
    "InputMediaPhoto",
    "InputMediaVideo",
    "InputMessageContent",
    "InputPaidMedia",
    "InputPaidMediaPhoto",
    "InputPaidMediaVideo",
    "InputProfilePhotoStatic",
    "InputProfilePhotoAnimated",
    "InputPollOption",
    "InputSticker",
    "InputStoryContentPhoto",
    "InputStoryContentVideo",
    "InputStoryContent",
    "InputTextMessageContent",
    "InputVenueMessageContent",
    "InputChecklistTask",
    "InputChecklist",
    "Invoice",
    "KeyboardButton",
    "KeyboardButtonPollType",
    "KeyboardButtonRequestChat",
    "KeyboardButtonRequestUsers",
    "LabeledPrice",
    "LinkPreviewOptions",
    "Listener",
    "Location",
    "LoginUrl",
    "MaskPosition",
    "MaybeInaccessibleMessage",
    "MenuButton",
    "MenuButtonCommands",
    "MenuButtonDefault",
    "MenuButtonWebApp",
    "Message",
    "MessageAutoDeleteTimerChanged",
    "MessageEntity",
    "MessageId",
    "MessageOrigin",
    "MessageOriginChannel",
    "MessageOriginChat",
    "MessageOriginHiddenUser",
    "MessageOriginUser",
    "MessageReactionCountUpdated",
    "MessageReactionUpdated",
    "OrderInfo",
    "PaidMedia",
    "PaidMediaInfo",
    "PaidMediaPhoto",
    "PaidMediaPreview",
    "PaidMediaPurchased",
    "PaidMediaVideo",
    "PassportData",
    "PassportElementError",
    "PassportElementErrorDataField",
    "PassportElementErrorFile",
    "PassportElementErrorFiles",
    "PassportElementErrorFrontSide",
    "PassportElementErrorReverseSide",
    "PassportElementErrorSelfie",
    "PassportElementErrorTranslationFile",
    "PassportElementErrorTranslationFiles",
    "PassportElementErrorUnspecified",
    "PassportFile",
    "PhotoSize",
    "Poll",
    "PollAnswer",
    "PollOption",
    "PreCheckoutQuery",
    "ProximityAlertTriggered",
    "ReactionCount",
    "ReactionType",
    "ReactionTypeCustomEmoji",
    "ReactionTypeEmoji",
    "RefundedPayment",
    "ReplyKeyboardMarkup",
    "ReplyKeyboardRemove",
    "ReplyParameters",
    "ResponseParameters",
    "RevenueWithdrawalState",
    "RevenueWithdrawalStateFailed",
    "RevenueWithdrawalStatePending",
    "RevenueWithdrawalStateSucceeded",
    "SentWebAppMessage",
    "SharedUser",
    "ShippingAddress",
    "ShippingOption",
    "ShippingQuery",
    "StarTransaction",
    "StarTransactions",
    "StarAmount",
    "Sticker",
    "StickerSet",
    "SuccessfulPayment",
    "Story",
    "StoryArea",
    "StoryAreaPosition",
    "StoryAreaTypeLink",
    "StoryAreaTypeLocation",
    "StoryAreaTypeSuggestedReaction",
    "StoryAreaTypeUniqueGift",
    "StoryAreaTypeWeather",
    "StoryAreaType",
    "SwitchInlineQueryChosenChat",
    "TextQuote",
    "TransactionPartnerAffiliateProgram",
    "TransactionPartnerChat",
    "TransactionPartnerFragment",
    "TransactionPartnerOther",
    "TransactionPartnerTelegramApi",
    "TransactionPartnerTelegramAds",
    "TransactionPartnerUser",
    "Update",
    "User",
    "UserChatBoosts",
    "UserProfilePhotos",
    "UsersShared",
    "UniqueGift",
    "UniqueGiftBackdrop",
    "UniqueGiftBackdropColors",
    "UniqueGiftInfo",
    "UniqueGiftModel",
    "UniqueGiftSymbol",
    "Venue",
    "Video",
    "VideoChatEnded",
    "VideoChatParticipantsInvited",
    "VideoChatScheduled",
    "VideoChatStarted",
    "VideoNote",
    "Voice",
    "WebAppData",
    "WebAppInfo",
    "WebhookInfo",
    "WriteAccessAllowed",
    "ParseMode",
    "ChatType",
    "MessageEntityType",
    "PreparedInlineMessage",
    "Gift",
    "Gifts",
    "OwnedGifts",
    "OwnedGiftRegular",
    "OwnedGiftUnique",
    "LocationAddress",
    "PaidMessagePriceChanged",
]



import tgram


class UpgradeGift:
    async def upgrade_gift(
        self: "tgram.TgBot",
        business_connection_id: str,
        owned_gift_id: str,
        keep_original_details: bool = None,
        star_count: int = None,
    ) -> bool:
        """
        Upgrades a given regular gift to a unique gift. Requires the can_transfer_and_upgrade_gifts business bot right.
        Additionally requires the can_transfer_stars business bot right if the upgrade is paid. Returns True on success.

        Parameters:
            business_connection_id (str): Unique identifier of the business connection.
            owned_gift_id (str): Unique identifier of the regular gift that should be upgraded to a unique one.
            keep_original_details (bool, optional): Pass True to keep the original gift text, sender and receiver in the upgraded gift.
            star_count (int, optional): The amount of Telegram Stars that will be paid for the upgrade from the business account balance.
        """
        result = await self(
            "upgradeGift",
            business_connection_id=business_connection_id,
            owned_gift_id=owned_gift_id,
            keep_original_details=keep_original_details,
            star_count=star_count,
        )
        return result["result"]



import tgram
from .type_ import Type_

from typing import Optional


class ReplyKeyboardRemove(Type_):
    """
    Upon receiving a message with this object, Telegram clients will remove the current custom keyboard and display the default letter-keyboard. By default, custom keyboards are displayed until a new keyboard is sent by a bot. An exception is made for one-time keyboards that are hidden immediately after the user presses a button (see ReplyKeyboardMarkup).

    Telegram Documentation: https://core.telegram.org/bots/api#replykeyboardremove

    :param selective: Optional. Use this parameter if you want to remove the keyboard for specific users only. Targets:
        1) users that are @mentioned in the text of the Message object; 2) if the bot's message is a reply (has
        reply_to_message_id), sender of the original message.Example: A user votes in a poll, bot returns confirmation
        message in reply to the vote and removes the keyboard for that user, while still showing the keyboard with poll options
        to users who haven't voted yet.
    :type selective: :obj:`bool`

    :return: Instance of the class
    :rtype: :class:`tgram.types.ReplyKeyboardRemove`
    """

    def __init__(
        self,
        selective: "bool" = None,
        me: "tgram.TgBot" = None,
        json: "dict" = None,
    ):
        super().__init__(me=me, json=json)
        self.remove_keyboard = True
        self.selective = selective

    @staticmethod
    def _parse(
        me: "tgram.TgBot" = None, d: dict = None, force: bool = None
    ) -> Optional["tgram.types.ReplyKeyboardRemove"]:
        return (
            ReplyKeyboardRemove(
                me=me,
                json=d,
                selective=d.get("selective"),
            )
            if d and (force or me and __class__.__name__ not in me._custom_types)
            else None
            if not d
            else Type_._custom_parse(
                __class__._parse(me=me, d=d, force=True),
                me._custom_types.get(__class__.__name__),
            )
        )



import tgram
from typing import Union
from tgram.types import ChatPermissions


class UnRestrictChatMember:
    async def unrestrict_chat_member(
        self: "tgram.TgBot",
        chat_id: Union[int, str],
        user_id: int,
        use_independent_chat_permissions: bool = None,
    ) -> bool:
        """
        Use this method to unrestrict a user in a supergroup.
        The bot must be an administrator in the supergroup for this to work and must have
        the appropriate admin rights.
        Telegram documentation: https://core.telegram.org/bots/api#restrictchatmember

        :param chat_id: Unique identifier for the target group or username of the target supergroup
            or channel (in the format @channelusername)
        :type chat_id: :obj:`int` or :obj:`str`

        :param user_id: Unique identifier of the target user
        :type user_id: :obj:`int`

        :param use_independent_chat_permissions: Pass True if chat permissions are set independently.
            Otherwise, the can_send_other_messages and can_add_web_page_previews permissions will imply the can_send_messages,
            can_send_audios, can_send_documents, can_send_photos, can_send_videos, can_send_video_notes, and can_send_voice_notes
            permissions; the can_send_polls permission will imply the can_send_messages permission.
        :type use_independent_chat_permissions: :obj:`bool`, optional

        :return: True on success
        :rtype: :obj:`bool`
        """

        result = await self(
            "restrictChatMember",
            chat_id=chat_id,
            user_id=user_id,
            permissions=ChatPermissions(
                True,
                True,
                True,
                True,
                True,
                True,
                True,
                True,
                True,
                True,
                True,
                True,
                True,
                True,
            ),
            use_independent_chat_permissions=use_independent_chat_permissions,
        )
        return result["result"]



import tgram
from .type_ import Type_

from typing import List, Optional


class BusinessOpeningHours(Type_):
    """

    This object represents business opening hours.

    Telegram documentation: https://core.telegram.org/bots/api#businessopeninghours

    :param time_zone_name: Unique name of the time zone for which the opening hours are defined
    :type time_zone_name: :obj:`str`

    :param opening_hours: List of time intervals describing business opening hours
    :type opening_hours: :obj:`list` of :class:`BusinessOpeningHoursInterval`

    :return: Instance of the class

    :rtype: :class:`BusinessOpeningHours`
    """

    def __init__(
        self,
        time_zone_name: "str" = None,
        opening_hours: List["tgram.types.BusinessOpeningHoursInterval"] = None,
        me: "tgram.TgBot" = None,
        json: "dict" = None,
    ):
        super().__init__(me=me, json=json)
        self.time_zone_name = time_zone_name
        self.opening_hours = opening_hours

    @staticmethod
    def _parse(
        me: "tgram.TgBot" = None, d: dict = None, force: bool = None
    ) -> Optional["tgram.types.BusinessOpeningHours"]:
        return (
            BusinessOpeningHours(
                me=me,
                json=d,
                time_zone_name=d.get("time_zone_name"),
                opening_hours=[
                    tgram.types.BusinessOpeningHoursInterval._parse(me=me, d=i)
                    for i in d.get("opening_hours")
                ]
                if d.get("opening_hours")
                else None,
            )
            if d and (force or me and __class__.__name__ not in me._custom_types)
            else None
            if not d
            else Type_._custom_parse(
                __class__._parse(me=me, d=d, force=True),
                me._custom_types.get(__class__.__name__),
            )
        )



import tgram

from tgram.types import MessageEntity, ParseMode
from typing import List, Union


class SendGift:
    async def send_gift(
        self: "tgram.TgBot",
        gift_id: str,
        user_id: int = None,
        chat_id: Union[int, str] = None,
        pay_for_upgrade: bool = None,
        text: str = None,
        text_parse_mode: ParseMode = None,
        text_entities: List[MessageEntity] = None,
    ) -> bool:
        """
        Sends a gift to the given user or channel chat. The gift can't be converted to Telegram Stars by the receiver. Returns True on success.

        Telegram documentation: https://core.telegram.org/bots/api#sendgift

        :param user_id: Required if chat_id is not specified. Unique identifier of the target user who will receive the gift.
        :type user_id: :obj:`int`

        :param chat_id: Required if user_id is not specified. Unique identifier for the chat or username of the channel (in the format @channelusername) that will receive the gift.
        :type chat_id: :obj:`int` or :obj:`str`

        :param gift_id: Identifier of the gift
        :type gift_id: :obj:`str`

        :param pay_for_upgrade: Pass True to pay for the gift upgrade from the bot's balance,
            thereby making the upgrade free for the receiver
        :type pay_for_upgrade: :obj:`bool`

        :param text: Text that will be shown along with the gift; 0-255 characters
        :type text: :obj:`str`

        :param text_parse_mode: Mode for parsing entities in the text. See formatting options for more details.
        Entities other than “bold”, “italic”, “underline”, “strikethrough”, “spoiler”, and “custom_emoji” are ignored.
        :type text_parse_mode: :obj:`str`

        :param text_entities: A JSON-serialized list of special entities that appear in the gift text. It can be specified instead of text_parse_mode. Entities other than “bold”, “italic”, “underline”, “strikethrough”, “spoiler”, and “custom_emoji” are ignored.
        :type text_entities: :obj:`list` of :class:`tgram.types.MessageEntity`

        :return: Returns True on success.
        :rtype: :obj:`bool`
        """
        result = await self(
            "sendGift",
            user_id=user_id,
            chat_id=chat_id,
            gift_id=gift_id,
            pay_for_upgrade=pay_for_upgrade,
            text=text,
            text_parse_mode=text_parse_mode,
            text_entities=text_entities,
        )

        return result["result"]



import tgram
from typing import List
from typing import Union
from tgram.types import ChatMember
from tgram.types import ChatMemberAdministrator
from tgram.types import ChatMemberOwner


class GetChatAdministrators:
    async def get_chat_administrators(
        self: "tgram.TgBot", chat_id: Union[int, str]
    ) -> List[Union[ChatMemberAdministrator, ChatMemberOwner]]:
        result = await self(
            "getChatAdministrators",
            chat_id=chat_id,
        )
        return [ChatMember._parse(me=self, d=i) for i in result["result"]]



import tgram
from .type_ import Type_

from typing import Optional


class InlineKeyboardButton(Type_):
    """
    This object represents one button of an inline keyboard. You must use exactly one of the optional fields.

    Telegram Documentation: https://core.telegram.org/bots/api#inlinekeyboardbutton

    :param text: Label text on the button
    :type text: :obj:`str`

    :param url: Optional. HTTP or tg:// URL to be opened when the button is pressed. Links tg://user?id=<user_id> can be
        used to mention a user by their ID without using a username, if this is allowed by their privacy settings.
    :type url: :obj:`str`

    :param callback_data: Optional. Data to be sent in a callback query to the bot when button is pressed, 1-64 bytes
    :type callback_data: :obj:`str`

    :param web_app: Optional. Description of the Web App that will be launched when the user presses the button. The Web
        App will be able to send an arbitrary message on behalf of the user using the method answerWebAppQuery. Available only
        in private chats between a user and the bot.
    :type web_app: :class:`tgram.types.WebAppInfo`

    :param login_url: Optional. An HTTPS URL used to automatically authorize the user. Can be used as a replacement for
        the Telegram Login Widget.
    :type login_url: :class:`tgram.types.LoginUrl`

    :param switch_inline_query: Optional. If set, pressing the button will prompt the user to select one of their chats,
        open that chat and insert the bot's username and the specified inline query in the input field. May be empty, in which
        case just the bot's username will be inserted.Note: This offers an easy way for users to start using your bot in inline
        mode when they are currently in a private chat with it. Especially useful when combined with switch_pm… actions - in
        this case the user will be automatically returned to the chat they switched from, skipping the chat selection screen.
    :type switch_inline_query: :obj:`str`

    :param switch_inline_query_current_chat: Optional. If set, pressing the button will insert the bot's username
        and the specified inline query in the current chat's input field. May be empty, in which case only the bot's username
        will be inserted.This offers a quick way for the user to open your bot in inline mode in the same chat - good for selecting
        something from multiple options.
    :type switch_inline_query_current_chat: :obj:`str`

    :param switch_inline_query_chosen_chat: Optional. If set, pressing the button will prompt the user to select one of their chats of the
        specified type, open that chat and insert the bot's username and the specified inline query in the input field
    :type switch_inline_query_chosen_chat: :class:`tgram.types.SwitchInlineQueryChosenChat`

    :param copy_text: Optional. Description of the button that copies the specified text to the clipboard.
    :type copy_text: :class:`tgram.types.CopyTextButton`

    :param callback_game: Optional. Description of the game that will be launched when the user presses the
        button. NOTE: This type of button must always be the first button in the first row.
    :type callback_game: :class:`tgram.types.CallbackGame`

    :param pay: Optional. Specify True, to send a Pay button. NOTE: This type of button must always be the first button in
        the first row and can only be used in invoice messages.
    :type pay: :obj:`bool`

    :return: Instance of the class
    :rtype: :class:`tgram.types.InlineKeyboardButton`
    """

    def __init__(
        self,
        text: "str" = None,
        callback_data: "str" = None,
        url: "str" = None,
        web_app: "tgram.types.WebAppInfo" = None,
        login_url: "tgram.types.LoginUrl" = None,
        switch_inline_query: "str" = None,
        switch_inline_query_current_chat: "str" = None,
        switch_inline_query_chosen_chat: "tgram.types.SwitchInlineQueryChosenChat" = None,
        copy_text: "tgram.types.CopyTextButton" = None,
        callback_game: "tgram.types.CallbackGame" = None,
        pay: "bool" = None,
        user_id: "int" = None,
        me: "tgram.TgBot" = None,
        json: "dict" = None,
    ):
        super().__init__(me=me, json=json)
        self.text = text
        self.callback_data = callback_data
        self.web_app = web_app
        self.login_url = login_url
        self.switch_inline_query = switch_inline_query
        self.switch_inline_query_current_chat = switch_inline_query_current_chat
        self.switch_inline_query_chosen_chat = switch_inline_query_chosen_chat
        self.copy_text = copy_text
        self.callback_game = callback_game
        self.pay = pay

        self.url = url or (f"tg://user?id={user_id}" if user_id is not None else None)

    @staticmethod
    def _parse(
        me: "tgram.TgBot" = None, d: dict = None, force: bool = None
    ) -> Optional["tgram.types.InlineKeyboardButton"]:
        return (
            InlineKeyboardButton(
                me=me,
                json=d,
                text=d.get("text"),
                url=d.get("url"),
                callback_data=d.get("callback_data"),
                web_app=tgram.types.WebAppInfo._parse(me=me, d=d.get("web_app")),
                login_url=tgram.types.LoginUrl._parse(me=me, d=d.get("login_url")),
                switch_inline_query=d.get("switch_inline_query"),
                switch_inline_query_current_chat=d.get(
                    "switch_inline_query_current_chat"
                ),
                switch_inline_query_chosen_chat=tgram.types.SwitchInlineQueryChosenChat._parse(
                    me=me, d=d.get("switch_inline_query_chosen_chat")
                ),
                copy_text=tgram.types.CopyTextButton._parse(
                    me=me, d=d.get("copy_text")
                ),
                callback_game=tgram.types.CallbackGame._parse(
                    me=me, d=d.get("callback_game")
                ),
                pay=d.get("pay"),
            )
            if d and (force or me and __class__.__name__ not in me._custom_types)
            else None
            if not d
            else Type_._custom_parse(
                __class__._parse(me=me, d=d, force=True),
                me._custom_types.get(__class__.__name__),
            )
        )



import tgram
from tgram.types import BotName


class GetMyName:
    async def get_my_name(self: "tgram.TgBot", language_code: str = None) -> BotName:
        """
        Use this method to get the current bot name for the given user language.
        Returns BotName on success.

        Telegram documentation: https://core.telegram.org/bots/api#getmyname

        :param language_code: Optional. A two-letter ISO 639-1 language code or an empty string
        :type language_code: :obj:`str`

        :return: :class:`tgram.types.BotName`
        """

        result = await self(
            "getMyName",
            language_code=language_code,
        )
        return BotName._parse(me=self, d=result["result"])



import tgram
from typing import List


class DeleteBusinessMessages:
    async def delete_business_messages(
        self: "tgram.TgBot",
        business_connection_id: str,
        message_ids: List[int],
    ) -> bool:
        """
        Deletes messages on behalf of a business account.
        Requires the can_delete_sent_messages business bot right to delete messages sent by the bot itself,
        or the can_delete_all_messages business bot right to delete any message.

        Telegram documentation: https://core.telegram.org/bots/api#deletebusinessmessages

        :param business_connection_id: Unique identifier of the business connection on behalf of which to delete the messages
        :type business_connection_id: :obj:`str`

        :param message_ids: A JSON-serialized list of 1-100 identifiers of messages to delete. All messages must be from the same chat.
        :type message_ids: :obj:`list[int]`

        :return: On success, returns True.
        :rtype: :obj:`bool`
        """

        result = await self(
            "deleteBusinessMessages",
            business_connection_id=business_connection_id,
            message_ids=message_ids,
        )
        return result["result"]



import tgram
from .type_ import Type_

from typing import Optional


class CallbackGame(Type_):
    def __init__(
        self,
        user_id: "int" = None,
        score: "int" = None,
        force: "bool" = None,
        disable_edit_message: "bool" = None,
        chat_id: "int" = None,
        message_id: "int" = None,
        inline_message_id: "str" = None,
        me: "tgram.TgBot" = None,
        json: "dict" = None,
    ):
        super().__init__(me=me, json=json)
        self.user_id = user_id
        self.score = score
        self.force = force
        self.disable_edit_message = disable_edit_message
        self.chat_id = chat_id
        self.message_id = message_id
        self.inline_message_id = inline_message_id

    @staticmethod
    def _parse(
        me: "tgram.TgBot" = None, d: dict = None, force: bool = None
    ) -> Optional["tgram.types.CallbackGame"]:
        return (
            CallbackGame(
                me=me,
                json=d,
                user_id=d.get("user_id"),
                score=d.get("score"),
                force=d.get("force"),
                disable_edit_message=d.get("disable_edit_message"),
                chat_id=d.get("chat_id"),
                message_id=d.get("message_id"),
                inline_message_id=d.get("inline_message_id"),
            )
            if d and (force or me and __class__.__name__ not in me._custom_types)
            else None
            if not d
            else Type_._custom_parse(
                __class__._parse(me=me, d=d, force=True),
                me._custom_types.get(__class__.__name__),
            )
        )



import tgram
from .type_ import Type_

from typing import List, Optional


class InputPollOption(Type_):
    """
    This object contains information about one answer option in a poll to send.

    Telegram Documentation: https://core.telegram.org/bots/api#inputpolloption

    :param text: Option text, 1-100 characters
    :type text: :obj:`str`

    :param text_parse_mode: Optional. Mode for parsing entities in the text. See formatting options for more details. Currently, only custom emoji entities are allowed
    :type text_parse_mode: :obj:`str`

    :param text_entities: Optional. A JSON-serialized list of special entities that appear in the poll option text. It can be specified instead of text_parse_mode
    :type text_entities: :obj:`list` of :class:`tgram.types.MessageEntity`

    :return: Instance of the class
    :rtype: :class:`tgram.types.PollOption`
    """

    def __init__(
        self,
        text: "str" = None,
        text_parse_mode: "str" = None,
        text_entities: List["tgram.types.MessageEntity"] = None,
        me: "tgram.TgBot" = None,
        json: "dict" = None,
    ):
        super().__init__(me=me, json=json)
        self.text = text
        self.text_parse_mode = text_parse_mode
        self.text_entities = text_entities

    @staticmethod
    def _parse(
        me: "tgram.TgBot" = None, d: dict = None, force: bool = None
    ) -> Optional["tgram.types.InputPollOption"]:
        return (
            InputPollOption(
                me=me,
                json=d,
                text=d.get("text"),
                text_parse_mode=d.get("text_parse_mode"),
                text_entities=[
                    tgram.types.MessageEntity._parse(me=me, d=i)
                    for i in d.get("text_entities")
                ]
                if d.get("text_entities")
                else None,
            )
            if d and (force or me and __class__.__name__ not in me._custom_types)
            else None
            if not d
            else Type_._custom_parse(
                __class__._parse(me=me, d=d, force=True),
                me._custom_types.get(__class__.__name__),
            )
        )



import tgram
from typing import List


class SetStickerKeywords:
    async def set_sticker_keywords(
        self: "tgram.TgBot", sticker: str, keywords: List[str] = None
    ) -> bool:
        """
        Use this method to change search keywords assigned to a regular or custom emoji sticker.
        The sticker must belong to a sticker set created by the bot.
        Returns True on success.

        :param sticker: File identifier of the sticker.
        :type sticker: :obj:`str`

        :param keywords: A JSON-serialized list of 0-20 search keywords for the sticker with total length of up to 64 characters
        :type keywords: :obj:`list` of :obj:`str`

        :return: On success, True is returned.
        :rtype: :obj:`bool`
        """

        result = await self(
            "setStickerKeywords",
            sticker=sticker,
            keywords=keywords,
        )
        return result["result"]



import tgram
from .type_ import Type_

from typing import Optional, Union
from pathlib import Path


class InputProfilePhotoStatic(Type_):
    """
    A static profile photo in the .JPG format.

    Telegram Documentation: https://core.telegram.org/bots/api#inputprofilephotostatic

    :param photo: The static profile photo. Profile photos can't be reused and can only be uploaded as a new file,
        so you can pass “attach://<file_attach_name>” if the photo was uploaded using multipart/form-data under <file_attach_name>.
        More information on Sending Files »
    :type photo: :obj:`str`

    :return: Instance of the class
    :rtype: :class:`tgram.types.InputProfilePhotoStatic`
    """

    def __init__(
        self,
        photo: Union["Path", "str"] = None,
        me: "tgram.TgBot" = None,
        json: "dict" = None,
    ):
        super().__init__(me=me, json=json)
        self.type = "static"
        self.photo = photo

    @staticmethod
    def _parse(
        me: "tgram.TgBot" = None, d: dict = None, force: bool = None
    ) -> Optional["tgram.types.InputProfilePhotoStatic"]:
        return (
            InputProfilePhotoStatic(
                me=me,
                json=d,
                photo=d.get("photo"),
            )
            if d and (force or me and __class__.__name__ not in me._custom_types)
            else None
            if not d
            else Type_._custom_parse(
                __class__._parse(me=me, d=d, force=True),
                me._custom_types.get(__class__.__name__),
            )
        )


class InputProfilePhotoAnimated(Type_):
    """
    An animated profile photo in the MPEG4 format.

    Telegram Documentation: https://core.telegram.org/bots/api#inputprofilephotoanimated

    :param animation: The animated profile photo. Profile photos can't be reused and can only be uploaded as a new file,
        so you can pass “attach://<file_attach_name>” if the photo was uploaded using multipart/form-data under <file_attach_name>.
        More information on Sending Files »
    :type animation: :obj:`str`
    :param main_frame_timestamp: Optional. Timestamp in seconds of the frame that will be used as the static profile photo. Defaults to 0.0.
    :type main_frame_timestamp: :obj:`float`, optional

    :return: Instance of the class
    :rtype: :class:`tgram.types.InputProfilePhotoAnimated`
    """

    def __init__(
        self,
        animation: Union["Path", "str"] = None,
        main_frame_timestamp: Optional[float] = None,
        me: "tgram.TgBot" = None,
        json: "dict" = None,
    ):
        super().__init__(me=me, json=json)
        self.type = "animated"
        self.animation = animation
        self.main_frame_timestamp = main_frame_timestamp

    @staticmethod
    def _parse(
        me: "tgram.TgBot" = None, d: dict = None, force: bool = None
    ) -> Optional["tgram.types.InputProfilePhotoAnimated"]:
        return (
            InputProfilePhotoAnimated(
                me=me,
                json=d,
                animation=d.get("animation"),
                main_frame_timestamp=d.get("main_frame_timestamp"),
            )
            if d and (force or me and __class__.__name__ not in me._custom_types)
            else None
            if not d
            else Type_._custom_parse(
                __class__._parse(me=me, d=d, force=True),
                me._custom_types.get(__class__.__name__),
            )
        )



import tgram
from .type_ import Type_

from typing import List, Optional


class InlineKeyboardMarkup(Type_):
    """
    This object represents an inline keyboard that appears right next to the message it belongs to.

    Telegram Documentation: https://core.telegram.org/bots/api#inlinekeyboardmarkup

    :param keyboard: :obj:`list` of button rows, each represented by an :obj:`list` of
        :class:`tgram.types.InlineKeyboardButton` objects
    :type keyboard: :obj:`list` of :obj:`list` of :class:`tgram.types.InlineKeyboardButton`

    :param row_width: number of :class:`tgram.types.InlineKeyboardButton` objects on each row
    :type row_width: :obj:`int`

    :return: Instance of the class
    :rtype: :class:`tgram.types.InlineKeyboardMarkup`
    """

    def __init__(
        self,
        inline_keyboard: List[List["tgram.types.InlineKeyboardButton"]] = None,
        me: "tgram.TgBot" = None,
        json: "dict" = None,
    ):
        super().__init__(me=me, json=json)
        self.inline_keyboard = inline_keyboard

    @staticmethod
    def _parse(
        me: "tgram.TgBot" = None, d: dict = None, force: bool = None
    ) -> Optional["tgram.types.InlineKeyboardMarkup"]:
        return (
            InlineKeyboardMarkup(
                me=me,
                json=d,
                inline_keyboard=[
                    [tgram.types.InlineKeyboardButton._parse(me=me, d=x) for x in i]
                    for i in d.get("inline_keyboard")
                ]
                if d.get("inline_keyboard")
                else None,
            )
            if d and (force or me and __class__.__name__ not in me._custom_types)
            else None
            if not d
            else Type_._custom_parse(
                __class__._parse(me=me, d=d, force=True),
                me._custom_types.get(__class__.__name__),
            )
        )



import tgram
from .type_ import Type_
from typing import Optional


class StoryAreaPosition(Type_):
    """
    Describes the position of a clickable area within a story.

    :param x_percentage: The abscissa of the area's center, as a percentage of the media width
    :type x_percentage: :obj:`float`
    :param y_percentage: The ordinate of the area's center, as a percentage of the media height
    :type y_percentage: :obj:`float`
    :param width_percentage: The width of the area's rectangle, as a percentage of the media width
    :type width_percentage: :obj:`float`
    :param height_percentage: The height of the area's rectangle, as a percentage of the media height
    :type height_percentage: :obj:`float`
    :param rotation_angle: The clockwise rotation angle of the rectangle, in degrees; 0-360
    :type rotation_angle: :obj:`float`
    :param corner_radius_percentage: The radius of the rectangle corner rounding, as a percentage of the media width
    :type corner_radius_percentage: :obj:`float`
    """

    def __init__(
        self,
        x_percentage: float = None,
        y_percentage: float = None,
        width_percentage: float = None,
        height_percentage: float = None,
        rotation_angle: float = None,
        corner_radius_percentage: float = None,
        me: "tgram.TgBot" = None,
        json: dict = None,
    ):
        super().__init__(me=me, json=json)
        self.x_percentage = x_percentage
        self.y_percentage = y_percentage
        self.width_percentage = width_percentage
        self.height_percentage = height_percentage
        self.rotation_angle = rotation_angle
        self.corner_radius_percentage = corner_radius_percentage

    @staticmethod
    def _parse(
        me: "tgram.TgBot" = None, d: dict = None, force: bool = None
    ) -> Optional["StoryAreaPosition"]:
        return (
            StoryAreaPosition(
                x_percentage=d.get("x_percentage"),
                y_percentage=d.get("y_percentage"),
                width_percentage=d.get("width_percentage"),
                height_percentage=d.get("height_percentage"),
                rotation_angle=d.get("rotation_angle"),
                corner_radius_percentage=d.get("corner_radius_percentage"),
            )
            if d and (force or me and __class__.__name__ not in me._custom_types)
            else None
            if not d
            else Type_._custom_parse(
                __class__._parse(me=me, d=d, force=True),
                me._custom_types.get(__class__.__name__),
            )
        )


class StoryAreaTypeLocation(Type_):
    """
    Describes a story area pointing to a location.

    :param type: Type of the area, always "location"
    :type type: :obj:`str`
    :param latitude: Location latitude in degrees
    :type latitude: :obj:`float`
    :param longitude: Location longitude in degrees
    :type longitude: :obj:`float`
    :param address: Optional. Address of the location
    :type address: :obj:`LocationAddress`
    """

    def __init__(
        self,
        latitude: float = None,
        longitude: float = None,
        address: "tgram.types.LocationAddress" = None,
        me: "tgram.TgBot" = None,
        json: dict = None,
    ):
        super().__init__(me=me, json=json)
        self.type = "location"
        self.latitude = latitude
        self.longitude = longitude
        self.address = address

    @staticmethod
    def _parse(
        me: "tgram.TgBot" = None, d: dict = None, force: bool = None
    ) -> Optional["StoryAreaTypeLocation"]:
        return (
            StoryAreaTypeLocation(
                latitude=d.get("latitude"),
                longitude=d.get("longitude"),
                address=tgram.types.LocationAddress._parse(me=me, d=d.get("address"))
                if d.get("address")
                else None,
            )
            if d and (force or me and __class__.__name__ not in me._custom_types)
            else None
            if not d
            else Type_._custom_parse(
                __class__._parse(me=me, d=d, force=True),
                me._custom_types.get(__class__.__name__),
            )
        )


class StoryAreaTypeSuggestedReaction(Type_):
    """
    Describes a story area pointing to a suggested reaction.

    :param type: Type of the area, always "suggested_reaction"
    :type type: :obj:`str`
    :param reaction_type: Type of the reaction
    :type reaction_type: :obj:`ReactionType`
    :param is_dark: Optional. Pass True if the reaction area has a dark background
    :type is_dark: :obj:`bool`
    :param is_flipped: Optional. Pass True if reaction area corner is flipped
    :type is_flipped: :obj:`bool`
    """

    def __init__(
        self,
        reaction_type: "tgram.types.ReactionType" = None,
        is_dark: bool = None,
        is_flipped: bool = None,
        me: "tgram.TgBot" = None,
        json: dict = None,
    ):
        super().__init__(me=me, json=json)
        self.type = "suggested_reaction"
        self.reaction_type = reaction_type
        self.is_dark = is_dark
        self.is_flipped = is_flipped

    @staticmethod
    def _parse(
        me: "tgram.TgBot" = None, d: dict = None, force: bool = None
    ) -> Optional["StoryAreaTypeSuggestedReaction"]:
        return (
            StoryAreaTypeSuggestedReaction(
                reaction_type=(
                    tgram.types.ReactionTypeCustomEmoji._parse(
                        me, d.get("reaction_type")
                    )
                    if d["reaction_type"]["type"] == "custom_emoji"
                    else tgram.types.ReactionTypeEmoji._parse(
                        me, d.get("reaction_type")
                    )
                    if d["reaction_type"]["type"] == "emoji"
                    else tgram.types.ReactionTypePaid._parse(me, d.get("reaction_type"))
                )
                if d.get("reaction_type")
                else None,
                is_dark=d.get("is_dark"),
                is_flipped=d.get("is_flipped"),
            )
            if d and (force or me and __class__.__name__ not in me._custom_types)
            else None
            if not d
            else Type_._custom_parse(
                __class__._parse(me=me, d=d, force=True),
                me._custom_types.get(__class__.__name__),
            )
        )


class StoryAreaTypeLink(Type_):
    """
    Describes a story area pointing to an HTTP or tg:// link.

    :param type: Type of the area, always "link"
    :type type: :obj:`str`
    :param url: HTTP or tg:// URL to be opened when the area is clicked
    :type url: :obj:`str`
    """

    def __init__(
        self,
        url: str = None,
        me: "tgram.TgBot" = None,
        json: dict = None,
    ):
        super().__init__(me=me, json=json)
        self.type = "link"
        self.url = url

    @staticmethod
    def _parse(
        me: "tgram.TgBot" = None, d: dict = None, force: bool = None
    ) -> Optional["StoryAreaTypeLink"]:
        return (
            StoryAreaTypeLink(
                url=d.get("url"),
            )
            if d and (force or me and __class__.__name__ not in me._custom_types)
            else None
            if not d
            else Type_._custom_parse(
                __class__._parse(me=me, d=d, force=True),
                me._custom_types.get(__class__.__name__),
            )
        )


class StoryAreaTypeWeather(Type_):
    """
    Describes a story area containing weather information.

    :param type: Type of the area, always "weather"
    :type type: :obj:`str`
    :param temperature: Temperature, in degree Celsius
    :type temperature: :obj:`float`
    :param emoji: Emoji representing the weather
    :type emoji: :obj:`str`
    :param background_color: A color of the area background in the ARGB format
    :type background_color: :obj:`int`
    """

    def __init__(
        self,
        temperature: float = None,
        emoji: str = None,
        background_color: int = None,
        me: "tgram.TgBot" = None,
        json: dict = None,
    ):
        super().__init__(me=me, json=json)
        self.type = "weather"
        self.temperature = temperature
        self.emoji = emoji
        self.background_color = background_color

    @staticmethod
    def _parse(
        me: "tgram.TgBot" = None, d: dict = None, force: bool = None
    ) -> Optional["StoryAreaTypeWeather"]:
        return (
            StoryAreaTypeWeather(
                temperature=d.get("temperature"),
                emoji=d.get("emoji"),
                background_color=d.get("background_color"),
            )
            if d and (force or me and __class__.__name__ not in me._custom_types)
            else None
            if not d
            else Type_._custom_parse(
                __class__._parse(me=me, d=d, force=True),
                me._custom_types.get(__class__.__name__),
            )
        )


class StoryAreaTypeUniqueGift(Type_):
    """
    Describes a story area pointing to a unique gift.

    :param type: Type of the area, always "unique_gift"
    :type type: :obj:`str`
    :param name: Unique name of the gift
    :type name: :obj:`str`
    """

    def __init__(
        self,
        name: str = None,
        me: "tgram.TgBot" = None,
        json: dict = None,
    ):
        super().__init__(me=me, json=json)
        self.type = "unique_gift"
        self.name = name

    @staticmethod
    def _parse(
        me: "tgram.TgBot" = None, d: dict = None, force: bool = None
    ) -> Optional["StoryAreaTypeUniqueGift"]:
        return (
            StoryAreaTypeUniqueGift(
                name=d.get("name"),
            )
            if d and (force or me and __class__.__name__ not in me._custom_types)
            else None
            if not d
            else Type_._custom_parse(
                __class__._parse(me=me, d=d, force=True),
                me._custom_types.get(__class__.__name__),
            )
        )


class StoryArea(Type_):
    """
    Describes a clickable area on a story media.

    :param position: Position of the area
    :type position: :obj:`StoryAreaPosition`
    :param type: Type of the area
    :type type: :obj:`StoryAreaType`
    """

    def __init__(
        self,
        position: StoryAreaPosition = None,
        type: "tgram.types.StoryAreaType" = None,
        me: "tgram.TgBot" = None,
        json: dict = None,
    ):
        super().__init__(me=me, json=json)
        self.position = position
        self.type = type

    @staticmethod
    def _parse(
        me: "tgram.TgBot" = None, d: dict = None, force: bool = None
    ) -> Optional["StoryArea"]:
        return (
            StoryArea(
                position=StoryAreaPosition._parse(me=me, d=d.get("position"))
                if d.get("position")
                else None,
                type=d.get("type"),
            )
            if d and (force or me and __class__.__name__ not in me._custom_types)
            else None
            if not d
            else Type_._custom_parse(
                __class__._parse(me=me, d=d, force=True),
                me._custom_types.get(__class__.__name__),
            )
        )



import tgram
from tgram.types import StarTransactions


class GetStarTransactions:
    async def get_star_transactions(
        self: "tgram.TgBot", offset: int = None, limit: int = None
    ) -> StarTransactions:
        """
        Returns the bot's Telegram Star transactions in chronological order.

        Telegram documentation: https://core.telegram.org/bots/api#getstartransactions

        :param offset: Number of transactions to skip in the response
        :type offset: :obj:`int`

        :param limit: The maximum number of transactions to be retrieved. Values between 1-100 are accepted. Defaults to 100.
        :type limit: :obj:`int`

        :return: On success, returns a StarTransactions object.
        :rtype: :obj:`tgram.types.StarTransactions`
        """

        result = await self(
            "getStarTransactions",
            offset=offset,
            limit=limit,
        )
        return StarTransactions._parse(me=self, d=result["result"])



import tgram
from .type_ import Type_

from typing import Optional


class ChatInviteLink(Type_):
    """
    Represents an invite link for a chat.

    Telegram Documentation: https://core.telegram.org/bots/api#chatinvitelink

    :param invite_link: The invite link. If the link was created by another chat administrator, then the second part of
        the link will be replaced with “…”.
    :type invite_link: :obj:`str`

    :param creator: Creator of the link
    :type creator: :class:`tgram.types.User`

    :param creates_join_request: True, if users joining the chat via the link need to be approved by chat administrators
    :type creates_join_request: :obj:`bool`

    :param is_primary: True, if the link is primary
    :type is_primary: :obj:`bool`

    :param is_revoked: True, if the link is revoked
    :type is_revoked: :obj:`bool`

    :param name: Optional. Invite link name
    :type name: :obj:`str`

    :param expire_date: Optional. Point in time (Unix timestamp) when the link will expire or has been expired
    :type expire_date: :obj:`int`

    :param member_limit: Optional. The maximum number of users that can be members of the chat simultaneously after
        joining the chat via this invite link; 1-99999
    :type member_limit: :obj:`int`

    :param pending_join_request_count: Optional. Number of pending join requests created using this link
    :type pending_join_request_count: :obj:`int`

    :return: Instance of the class
    :rtype: :class:`tgram.types.ChatInviteLink`
    """

    def __init__(
        self,
        invite_link: "str" = None,
        creator: "tgram.types.User" = None,
        creates_join_request: "bool" = None,
        is_primary: "bool" = None,
        is_revoked: "bool" = None,
        name: "str" = None,
        expire_date: "int" = None,
        member_limit: "int" = None,
        pending_join_request_count: "int" = None,
        me: "tgram.TgBot" = None,
        json: "dict" = None,
    ):
        super().__init__(me=me, json=json)
        self.invite_link = invite_link
        self.creator = creator
        self.creates_join_request = creates_join_request
        self.is_primary = is_primary
        self.is_revoked = is_revoked
        self.name = name
        self.expire_date = expire_date
        self.member_limit = member_limit
        self.pending_join_request_count = pending_join_request_count

    @staticmethod
    def _parse(
        me: "tgram.TgBot" = None, d: dict = None, force: bool = None
    ) -> Optional["tgram.types.ChatInviteLink"]:
        return (
            ChatInviteLink(
                me=me,
                json=d,
                invite_link=d.get("invite_link"),
                creator=tgram.types.User._parse(me=me, d=d.get("creator")),
                creates_join_request=d.get("creates_join_request"),
                is_primary=d.get("is_primary"),
                is_revoked=d.get("is_revoked"),
                name=d.get("name"),
                expire_date=d.get("expire_date"),
                member_limit=d.get("member_limit"),
                pending_join_request_count=d.get("pending_join_request_count"),
            )
            if d and (force or me and __class__.__name__ not in me._custom_types)
            else None
            if not d
            else Type_._custom_parse(
                __class__._parse(me=me, d=d, force=True),
                me._custom_types.get(__class__.__name__),
            )
        )



import tgram


class RemoveBusinessAccountProfilePhoto:
    async def remove_business_account_profile_photo(
        self: "tgram.TgBot",
        business_connection_id: str,
        is_public: bool = None,
    ) -> bool:
        """
        Removes the current profile photo of a managed business account.
        Requires the can_edit_profile_photo business bot right.

        Telegram documentation: https://core.telegram.org/bots/api#removebusinessaccountprofilephoto

        :param business_connection_id: Unique identifier of the business connection
        :type business_connection_id: :obj:`str`

        :param is_public: Pass True to remove the public photo, which is visible even if the main photo is hidden by the business account's privacy settings. After the main photo is removed, the previous profile photo (if present) becomes the main photo.
        :type is_public: :obj:`bool`, optional

        :return: On success, returns True.
        :rtype: :obj:`bool`
        """
        result = await self(
            "removeBusinessAccountProfilePhoto",
            business_connection_id=business_connection_id,
            is_public=is_public,
        )
        return result["result"]



import tgram
from typing import Union


class DeleteMessage:
    async def delete_message(
        self: "tgram.TgBot", chat_id: Union[int, str], message_id: int
    ) -> bool:
        """
        Use this method to delete a message, including service messages, with the following limitations:
        - A message can only be deleted if it was sent less than 48 hours ago.
        - A dice message in a private chat can only be deleted if it was sent more than 24 hours ago.
        - Bots can delete outgoing messages in private chats, groups, and supergroups.
        - Bots can delete incoming messages in private chats.
        - Bots granted can_post_messages permissions can delete outgoing messages in channels.
        - If the bot is an administrator of a group, it can delete any message there.
        - If the bot has can_delete_messages permission in a supergroup or a channel, it can delete any message there.
        Returns True on success.

        Telegram documentation: https://core.telegram.org/bots/api#deletemessage

        :param chat_id: Unique identifier for the target chat or username of the target channel (in the format @channelusername)
        :type chat_id: :obj:`int` or :obj:`str`

        :param message_id: Identifier of the message to delete
        :type message_id: :obj:`int`

        :param timeout: Timeout in seconds for the request.
        :type timeout: :obj:`int`

        :return: Returns True on success.
        :rtype: :obj:`bool`
        """

        result = await self(
            "deleteMessage",
            chat_id=chat_id,
            message_id=message_id,
        )
        return result["result"]



import tgram


class RefundStarPayment:
    async def refund_star_payment(
        self: "tgram.TgBot", user_id: int, telegram_payment_charge_id: str
    ) -> bool:
        """
        Refunds a successful payment in Telegram Stars. Returns True on success.

        Telegram documentation: https://core.telegram.org/bots/api#refundstarpayment

        :param user_id: Identifier of the user whose payment will be refunded
        :type user_id: :obj:`int`

        :param telegram_payment_charge_id: Telegram payment identifier
        :type telegram_payment_charge_id: :obj:`str`

        :return: On success, True is returned.
        :rtype: :obj:`bool`
        """

        result = await self(
            "refundStarPayment",
            user_id=user_id,
            telegram_payment_charge_id=telegram_payment_charge_id,
        )
        return result["result"]



import tgram
from .type_ import Type_

from typing import Optional


class InaccessibleMessage(Type_):
    """
    This object describes a message that was deleted or is otherwise inaccessible to the bot.

    Telegram documentation: https://core.telegram.org/bots/api#inaccessiblemessage

    :param chat: Chat the message belonged to
    :type chat: :class:`Chat`

    :param message_id: Unique message identifier inside the chat
    :type message_id: :obj:`int`

    :param date: Always 0. The field can be used to differentiate regular and inaccessible messages.
    :type date: :obj:`int`

    :return: Instance of the class
    :rtype: :class:`InaccessibleMessage`
    """

    def __init__(
        self,
        chat: "tgram.types.Chat" = None,
        message_id: "int" = None,
        date: "int" = None,
        me: "tgram.TgBot" = None,
        json: "dict" = None,
    ):
        super().__init__(me=me, json=json)
        self.chat = chat
        self.message_id = message_id
        self.date = date

    @staticmethod
    def _parse(
        me: "tgram.TgBot" = None, d: dict = None, force: bool = None
    ) -> Optional["tgram.types.InaccessibleMessage"]:
        return (
            InaccessibleMessage(
                me=me,
                json=d,
                chat=tgram.types.Chat._parse(me=me, d=d.get("chat")),
                message_id=d.get("message_id"),
                date=d.get("date"),
            )
            if d and (force or me and __class__.__name__ not in me._custom_types)
            else None
            if not d
            else Type_._custom_parse(
                __class__._parse(me=me, d=d, force=True),
                me._custom_types.get(__class__.__name__),
            )
        )



import tgram
from .type_ import Type_

from typing import Optional, List


class TransactionPartnerUser(Type_):
    """
    Describes a transaction with a user.

    Telegram documentation: https://core.telegram.org/bots/api#transactionpartneruser

    :param type: Type of the transaction partner, always “user”
    :type type: :obj:`str`

    :param transaction_type: Type of the transaction, currently one of “invoice_payment”, “paid_media_payment”, “gift_purchase”, “premium_purchase”, “business_account_transfer”
    :type transaction_type: :obj:`str`

    :param user: Information about the user
    :type user: :class:`User`

    :param affiliate: Optional. Information about the affiliate that received a commission via this transaction. Can be available only for “invoice_payment” and “paid_media_payment” transactions.
    :type affiliate: :class:`AffiliateInfo`, optional

    :param invoice_payload: Optional. Bot-specified invoice payload. Can be available only for “invoice_payment” transactions.
    :type invoice_payload: :obj:`str`, optional

    :param subscription_period: Optional. The duration of the paid subscription. Can be available only for “invoice_payment” transactions.
    :type subscription_period: :obj:`int`, optional

    :param paid_media: Optional. Information about the paid media bought by the user; for “paid_media_payment” transactions only
    :type paid_media: List[:class:`PaidMedia`], optional

    :param paid_media_payload: Optional. Bot-specified paid media payload. Can be available only for “paid_media_payment” transactions.
    :type paid_media_payload: :obj:`str`, optional

    :param gift: Optional. The gift sent to the user by the bot; for “gift_purchase” transactions only
    :type gift: :class:`Gift`, optional

    :param premium_subscription_duration: Optional. Number of months the gifted Telegram Premium subscription will be active for; for “premium_purchase” transactions only
    :type premium_subscription_duration: :obj:`int`, optional

    :return: Instance of the class
    :rtype: :class:`TransactionPartnerUser`
    """

    def __init__(
        self,
        user: "tgram.types.User" = None,
        transaction_type: str = None,
        affiliate: "tgram.types.AffiliateInfo" = None,
        invoice_payload: str = None,
        subscription_period: int = None,
        paid_media: List["tgram.types.PaidMedia"] = None,
        paid_media_payload: str = None,
        gift: "tgram.types.Gift" = None,
        premium_subscription_duration: int = None,
        me: "tgram.TgBot" = None,
        json: dict = None,
    ):
        super().__init__(me=me, json=json)
        self.type = "user"
        self.transaction_type = transaction_type
        self.user = user
        self.affiliate = affiliate
        self.invoice_payload = invoice_payload
        self.subscription_period = subscription_period
        self.paid_media = paid_media
        self.paid_media_payload = paid_media_payload
        self.gift = gift
        self.premium_subscription_duration = premium_subscription_duration

    @staticmethod
    def _parse(
        me: "tgram.TgBot" = None, d: dict = None, force: bool = None
    ) -> Optional["tgram.types.TransactionPartnerUser"]:
        return (
            TransactionPartnerUser(
                me=me,
                json=d,
                user=tgram.types.User._parse(me=me, d=d.get("user")),
                transaction_type=d.get("transaction_type"),
                affiliate=tgram.types.AffiliateInfo._parse(me=me, d=d.get("affiliate")),
                invoice_payload=d.get("invoice_payload"),
                subscription_period=d.get("subscription_period"),
                paid_media=[
                    (
                        tgram.types.PaidMediaPreview._parse(me=me, d=i)
                        if i["type"] == "preview"
                        else tgram.types.PaidMediaPhoto._parse(me=me, d=i)
                        if i["type"] == "photo"
                        else tgram.types.PaidMediaVideo._parse(me=me, d=i)
                    )
                    for i in d.get("paid_media")
                ]
                if d.get("paid_media")
                else None,
                paid_media_payload=d.get("paid_media_payload"),
                gift=tgram.types.Gift._parse(me=me, d=d.get("gift")),
                premium_subscription_duration=d.get("premium_subscription_duration"),
            )
            if d and (force or me and __class__.__name__ not in me._custom_types)
            else None
            if not d
            else Type_._custom_parse(
                __class__._parse(me=me, d=d, force=True),
                me._custom_types.get(__class__.__name__),
            )
        )



import tgram
from .type_ import Type_

from typing import Optional


class Dice(Type_):
    """
    This object represents an animated emoji that displays a random value.

    Telegram Documentation: https://core.telegram.org/bots/api#dice

    :param emoji: Emoji on which the dice throw animation is based
    :type emoji: :obj:`str`

    :param value: Value of the dice, 1-6 for “🎲”, “🎯” and “🎳” base emoji, 1-5 for “🏀” and “⚽” base emoji, 1-64 for “🎰” base emoji
    :type value: :obj:`int`

    :return: Instance of the class
    :rtype: :class:`tgram.types.Dice`
    """

    def __init__(
        self,
        emoji: "str" = None,
        value: "int" = None,
        me: "tgram.TgBot" = None,
        json: "dict" = None,
    ):
        super().__init__(me=me, json=json)
        self.emoji = emoji
        self.value = value

    @staticmethod
    def _parse(
        me: "tgram.TgBot" = None, d: dict = None, force: bool = None
    ) -> Optional["tgram.types.Dice"]:
        return (
            Dice(me=me, json=d, emoji=d.get("emoji"), value=d.get("value"))
            if d and (force or me and __class__.__name__ not in me._custom_types)
            else None
            if not d
            else Type_._custom_parse(
                __class__._parse(me=me, d=d, force=True),
                me._custom_types.get(__class__.__name__),
            )
        )



import tgram

from typing import List


class EditStory:
    async def edit_story(
        self: "tgram.TgBot",
        business_connection_id: str,
        story_id: int,
        content: "tgram.types.InputStoryContent",
        caption: str = None,
        parse_mode: str = None,
        caption_entities: List["tgram.types.MessageEntity"] = None,
        areas: List["tgram.types.StoryArea"] = None,
    ) -> "tgram.types.Story":
        """
        Edits a story previously posted by the bot on behalf of a managed business account.
        Requires the can_manage_stories business bot right.

        Telegram documentation: https://core.telegram.org/bots/api#editstory

        :param business_connection_id: Unique identifier of the business connection
        :type business_connection_id: :obj:`str`

        :param story_id: Unique identifier of the story to edit
        :type story_id: :obj:`int`

        :param content: Content of the story
        :type content: :class:`tgram.types.InputStoryContent`

        :param caption: Caption of the story, 0-2048 characters after entities parsing
        :type caption: :obj:`str`, optional

        :param parse_mode: Mode for parsing entities in the story caption
        :type parse_mode: :obj:`str`, optional

        :param caption_entities: A JSON-serialized list of special entities that appear in the caption
        :type caption_entities: :obj:`list`, optional

        :param areas: A JSON-serialized list of clickable areas to be shown on the story
        :type areas: :obj:`list`, optional

        :return: On success, returns a Story object.
        :rtype: :class:`tgram.types.Story`
        """
        result = await self(
            "editStory",
            business_connection_id=business_connection_id,
            story_id=story_id,
            content=content,
            caption=caption,
            parse_mode=parse_mode,
            caption_entities=caption_entities,
            areas=areas,
        )
        return tgram.types.Story._parse(me=self, d=result["result"])



import tgram
from typing import Union
from tgram.types import Message


class ForwardMessage:
    async def forward_message(
        self: "tgram.TgBot",
        chat_id: Union[int, str],
        from_chat_id: Union[int, str],
        message_id: int,
        message_thread_id: int = None,
        video_start_timestamp: int = None,
        disable_notification: bool = None,
        protect_content: bool = None,
    ) -> Message:
        """
        Use this method to forward messages of any kind.

        Telegram documentation: https://core.telegram.org/bots/api#forwardmessage

        :param disable_notification: Sends the message silently. Users will receive a notification with no sound
        :type disable_notification: :obj:`bool`

        :param chat_id: Unique identifier for the target chat or username of the target channel (in the format @channelusername)
        :type chat_id: :obj:`int` or :obj:`str`

        :param from_chat_id: Unique identifier for the chat where the original message was sent (or channel username in the format @channelusername)
        :type from_chat_id: :obj:`int` or :obj:`str`

        :param message_id: Message identifier in the chat specified in from_chat_id
        :type message_id: :obj:`int`

        :param video_start_timestamp: New start timestamp for the forwarded video in the message
        :type video_start_timestamp: :obj:`int`

        :param protect_content: Protects the contents of the forwarded message from forwarding and saving
        :type protect_content: :obj:`bool`

        :param timeout: Timeout in seconds for the request.
        :type timeout: :obj:`int`

        :param message_thread_id: Unique identifier for the target message thread (topic) of the forum; for forum supergroups only
        :type message_thread_id: :obj:`int`

        :return: On success, the sent Message is returned.
        :rtype: :class:`tgram.types.Message`
        """

        result = await self(
            "forwardMessage",
            chat_id=chat_id,
            from_chat_id=from_chat_id,
            message_id=message_id,
            message_thread_id=message_thread_id,
            video_start_timestamp=video_start_timestamp,
            disable_notification=disable_notification,
            protect_content=protect_content
            if protect_content is not None
            else self.protect_content,
        )
        return Message._parse(me=self, d=result["result"])



import logging

log = logging.getLogger(__name__)

HTML_MENTION = '<a href="tg://user?id={user_id}">{name}</a>'
MARKDOWN_MENTION = "[{name}](tg://user?id={user_id})"


class Mention:
    def __init__(self, name: str, user_id: int) -> None:
        self.name = name
        self.user_id = user_id

    @property
    def markdown(self) -> str:
        return MARKDOWN_MENTION.format(name=self.name, user_id=self.user_id)

    @property
    def html(self) -> str:
        return HTML_MENTION.format(name=self.name, user_id=self.user_id)

    def __str__(self) -> str:
        log.warning(
            "Calling Mention object returns only the name. "
            "If you want a formatted mention, use the 'markdown' or 'html' properties instead."
        )
        return self.name



import tgram
from .type_ import Type_

from typing import Optional


class ChatBackground(Type_):
    """
    This object represents a chat background.

    Telegram documentation: https://core.telegram.org/bots/api#chatbackground

    :param type: Type of the background
    :type type: :class:`BackgroundType`

    :return: Instance of the class
    :rtype: :class:`ChatBackground`
    """

    def __init__(
        self,
        type: "tgram.types.BackgroundType" = None,
        me: "tgram.TgBot" = None,
        json: "dict" = None,
    ):
        super().__init__(me=me, json=json)
        self.type = type

    @staticmethod
    def _parse(
        me: "tgram.TgBot" = None, d: dict = None, force: bool = None
    ) -> Optional["tgram.types.ChatBackground"]:
        return (
            ChatBackground(
                me=me,
                json=d,
                type=tgram.types.BackgroundType._parse(me=me, d=d.get("type")),
            )
            if d and (force or me and __class__.__name__ not in me._custom_types)
            else None
            if not d
            else Type_._custom_parse(
                __class__._parse(me=me, d=d, force=True),
                me._custom_types.get(__class__.__name__),
            )
        )



import tgram
from .type_ import Type_

from typing import Optional


class ForumTopicCreated(Type_):
    """
    This object represents a service message about a new forum topic created in the chat.

    Telegram documentation: https://core.telegram.org/bots/api#forumtopiccreated

    :param name: Name of the topic
    :type name: :obj:`str`

    :param icon_color: Color of the topic icon in RGB format
    :type icon_color: :obj:`int`

    :param icon_custom_emoji_id: Optional. Unique identifier of the custom emoji shown as the topic icon
    :type icon_custom_emoji_id: :obj:`str`

    :return: Instance of the class
    :rtype: :class:`tgram.types.ForumTopicCreated`
    """

    def __init__(
        self,
        name: "str" = None,
        icon_color: "int" = None,
        icon_custom_emoji_id: "str" = None,
        me: "tgram.TgBot" = None,
        json: "dict" = None,
    ):
        super().__init__(me=me, json=json)
        self.name = name
        self.icon_color = icon_color
        self.icon_custom_emoji_id = icon_custom_emoji_id

    @staticmethod
    def _parse(
        me: "tgram.TgBot" = None, d: dict = None, force: bool = None
    ) -> Optional["tgram.types.ForumTopicCreated"]:
        return (
            ForumTopicCreated(
                me=me,
                json=d,
                name=d.get("name"),
                icon_color=d.get("icon_color"),
                icon_custom_emoji_id=d.get("icon_custom_emoji_id"),
            )
            if d and (force or me and __class__.__name__ not in me._custom_types)
            else None
            if not d
            else Type_._custom_parse(
                __class__._parse(me=me, d=d, force=True),
                me._custom_types.get(__class__.__name__),
            )
        )



import tgram
from typing import List
from tgram.types import LabeledPrice


class CreateInvoiceLink:
    async def create_invoice_link(
        self: "tgram.TgBot",
        title: str,
        description: str,
        payload: str,
        currency: str,
        prices: List[LabeledPrice],
        business_connection_id: str = None,
        subscription_period: int = None,
        provider_token: str = None,
        max_tip_amount: int = None,
        suggested_tip_amounts: List[int] = None,
        provider_data: str = None,
        photo_url: str = None,
        photo_size: int = None,
        photo_width: int = None,
        photo_height: int = None,
        need_name: bool = None,
        need_phone_number: bool = None,
        need_email: bool = None,
        need_shipping_address: bool = None,
        send_phone_number_to_provider: bool = None,
        send_email_to_provider: bool = None,
        is_flexible: bool = None,
    ) -> str:
        """
        Use this method to create a link for an invoice.
        Returns the created invoice link as String on success.

        Telegram documentation:
        https://core.telegram.org/bots/api#createinvoicelink

        :param title: Product name, 1-32 characters
        :type title: :obj:`str`

        :param description: Product description, 1-255 characters
        :type description: :obj:`str`

        :param payload: Bot-defined invoice payload, 1-128 bytes. This will not be displayed to the user,
            use for your internal processes.
        :type payload: :obj:`str`

        :param provider_token: Payments provider token, obtained via @Botfather; Pass None to omit the parameter
            to use "XTR" currency
        :type provider_token: :obj:`str`

        :param currency: Three-letter ISO 4217 currency code,
            see https://core.telegram.org/bots/payments#supported-currencies
        :type currency: :obj:`str`

        :param prices: Price breakdown, a list of components
            (e.g. product price, tax, discount, delivery cost, delivery tax, bonus, etc.)
        :type prices: :obj:`list` of :obj:`tgram.types.LabeledPrice`

        :param business_connection_id: Unique identifier of the business connection on behalf of which the link will be created.
        :type business_connection_id: :obj:`str`

        :param subscription_period: The number of seconds the subscription will be active for before the next payment.
        The currency must be set to “XTR” (Telegram Stars) if the parameter is used. Currently, it must always be 2592000 (30 days) if specified.
        :type subscription_period: :obj:`int`

        :param max_tip_amount: The maximum accepted amount for tips in the smallest units of the currency
        :type max_tip_amount: :obj:`int`

        :param suggested_tip_amounts: A JSON-serialized array of suggested amounts of tips in the smallest
            units of the currency.  At most 4 suggested tip amounts can be specified. The suggested tip
            amounts must be positive, passed in a strictly increased order and must not exceed max_tip_amount.
        :type suggested_tip_amounts: :obj:`list` of :obj:`int`

        :param provider_data: A JSON-serialized data about the invoice, which will be shared with the payment provider.
            A detailed description of required fields should be provided by the payment provider.
        :type provider_data: :obj:`str`

        :param photo_url: URL of the product photo for the invoice. Can be a photo of the goods
            or a photo of the invoice. People like it better when they see a photo of what they are paying for.
        :type photo_url: :obj:`str`

        :param photo_size: Photo size in bytes
        :type photo_size: :obj:`int`

        :param photo_width: Photo width
        :type photo_width: :obj:`int`

        :param photo_height: Photo height
        :type photo_height: :obj:`int`

        :param need_name: Pass True, if you require the user's full name to complete the order
        :type need_name: :obj:`bool`

        :param need_phone_number: Pass True, if you require the user's phone number to complete the order
        :type need_phone_number: :obj:`bool`

        :param need_email: Pass True, if you require the user's email to complete the order
        :type need_email: :obj:`bool`

        :param need_shipping_address: Pass True, if you require the user's shipping address to complete the order
        :type need_shipping_address: :obj:`bool`

        :param send_phone_number_to_provider: Pass True, if user's phone number should be sent to provider
        :type send_phone_number_to_provider: :obj:`bool`

        :param send_email_to_provider: Pass True, if user's email address should be sent to provider
        :type send_email_to_provider: :obj:`bool`

        :param is_flexible: Pass True, if the final price depends on the shipping method
        :type is_flexible: :obj:`bool`

        :return: Created invoice link as String on success.
        :rtype: :obj:`str`
        """

        result = await self(
            "createInvoiceLink",
            title=title,
            description=description,
            payload=payload,
            currency=currency,
            prices=prices,
            business_connection_id=business_connection_id,
            subscription_period=subscription_period,
            provider_token=provider_token,
            max_tip_amount=max_tip_amount,
            suggested_tip_amounts=suggested_tip_amounts,
            provider_data=provider_data,
            photo_url=photo_url,
            photo_size=photo_size,
            photo_width=photo_width,
            photo_height=photo_height,
            need_name=need_name,
            need_phone_number=need_phone_number,
            need_email=need_email,
            need_shipping_address=need_shipping_address,
            send_phone_number_to_provider=send_phone_number_to_provider,
            send_email_to_provider=send_email_to_provider,
            is_flexible=is_flexible,
        )
        return result["result"]



import tgram
from tgram.types import StarAmount


class GetMyStarBalance:
    async def get_my_star_balance(self: "tgram.TgBot") -> StarAmount:
        """
        Use this method to get the current Telegram Stars balance of the bot.
        On success, returns a StarAmount object.

        Telegram documentation: https://core.telegram.org/bots/api#getmystarbalance

        :return: Current Stars balance of the bot
        :rtype: :class:`tgram.types.StarAmount`
        """
        result = await self("getMyStarBalance")
        return StarAmount._parse(me=self, d=result["result"])



import tgram
from typing import List
from typing import Union


class DeleteMessages:
    async def delete_messages(
        self: "tgram.TgBot", chat_id: Union[int, str], message_ids: List[int]
    ) -> bool:
        """
        Use this method to delete multiple messages simultaneously.
        If some of the specified messages can't be found, they are skipped. Returns True on success.

        Telegram documentation: https://core.telegram.org/bots/api#deletemessages

        :param chat_id: Unique identifier for the target chat or username of the target channel (in the format @channelusername)
        :type chat_id: :obj:`int` or :obj:`str`

        :param message_ids: Identifiers of the messages to be deleted
        :type message_ids: :obj:`list` of :obj:`int`

        :return: Returns True on success.

        """

        result = await self(
            "deleteMessages",
            chat_id=chat_id,
            message_ids=message_ids,
        )
        return result["result"]



import tgram
from .type_ import Type_

from typing import List, Optional
from tgram.utils import String


class ChecklistTask(Type_):
    """
    Describes a task in a checklist.

    :param id: Unique identifier of the task
    :type id: :obj:`int`

    :param text: Text of the task
    :type text: :class:`tgram.utils.String`

    :param text_entities: Optional. Special entities that appear in the task text
    :type text_entities: :obj:`list` of :class:`tgram.types.MessageEntity`

    :param completed_by_user: Optional. User that completed the task; omitted if the task wasn't completed
    :type completed_by_user: :class:`tgram.types.User`

    :param completion_date: Optional. Point in time (Unix timestamp) when the task was completed; 0 if the task wasn't completed
    :type completion_date: :obj:`int`
    """

    def __init__(
        self,
        id: int = None,
        text: "str" = None,
        text_entities: List["tgram.types.MessageEntity"] = None,
        completed_by_user: "tgram.types.User" = None,
        completion_date: int = None,
        me: "tgram.TgBot" = None,
        json: "dict" = None,
    ):
        super().__init__(me=me, json=json)
        self.id = id
        self.text = String(text).put(text_entities) if text else None
        self.text_entities = text_entities
        self.completed_by_user = completed_by_user
        self.completion_date = completion_date

    @staticmethod
    def _parse(
        me: "tgram.TgBot" = None, d: dict = None, force: bool = None
    ) -> Optional["tgram.types.ChecklistTask"]:
        return (
            ChecklistTask(
                me=me,
                json=d,
                id=d.get("id"),
                text=d.get("text"),
                text_entities=[
                    tgram.types.MessageEntity._parse(me=me, d=i)
                    for i in d.get("text_entities")
                ]
                if d.get("text_entities")
                else None,
                completed_by_user=tgram.types.User._parse(
                    me=me, d=d.get("completed_by_user")
                ),
                completion_date=d.get("completion_date"),
            )
            if d and (force or me and __class__.__name__ not in me._custom_types)
            else None
            if not d
            else Type_._custom_parse(
                __class__._parse(me=me, d=d, force=True),
                me._custom_types.get(__class__.__name__),
            )
        )
